# encoding: utf-8
#
# 銀行決済申込 要求サンプル
#

#
# MDKへパスを通す
#
require './MdkRuby/tgMdk/lib/tg_mdk'
require './MdkRuby/tgMdk/lib/tg_mdk/mdk_dto'

#-------------------------------------------------------
# 決済方式
#
# ATM決済 : atm
# ネットバンク決済銀行リンク方式（PC） : netbank-pc
# ネットバンク決済銀行リンク方式（docomo） : netbank-docomo
# ネットバンク決済銀行リンク方式（SoftBank） : netbank-softbank
# ネットバンク決済銀行リンク方式（au） : netbank-au
# (※ご注意： ネットバンク決済の部分は、コマンドラインサンプルで
#    画面のリンクはできないため、参考としてここに記述しております。)
#-------------------------------------------------------
@service_option_type = "atm"

#-------------------------------------------------------
# 取引ID
#-------------------------------------------------------
@order_id = "dummy" + Time.now.to_i.to_s

#-------------------------------------------------------
# 決済金額
#-------------------------------------------------------
@payment_amount = "10"

#-------------------------------------------------------
# 顧客名1
#-------------------------------------------------------
@client_name1 = "顧客　氏名"

#-------------------------------------------------------
# 顧客名カナ1
#-------------------------------------------------------
@client_kana1 = "コキャクシメイカナ"

#-------------------------------------------------------
# 郵便番号1
#-------------------------------------------------------
@postal_code1 = "123"

#-------------------------------------------------------
# 郵便番号2
#-------------------------------------------------------
@postal_code2 = "4567"

#-------------------------------------------------------
# 住所
#-------------------------------------------------------
@address = "東京都港区１－６－１"

#-------------------------------------------------------
# 電話番号
#-------------------------------------------------------
@telephone_number = "0123456789"

#-------------------------------------------------------
# 支払期限
#-------------------------------------------------------
@payment_limit = (Time.now + 24*60*60*5).strftime("%Y%m%d").to_s

#-------------------------------------------------------
# 成約日
#-------------------------------------------------------
@agreement_date = (Time.now - 24*60*60*1).strftime("%Y%m%d").to_s

#-------------------------------------------------------
# 請求内容
#-------------------------------------------------------
@contents = "表示インフォメーション"

#-------------------------------------------------------
# 請求内容カナ
#-------------------------------------------------------
@contents_kana = "ヒョウジインフォメーションカナ"


#==========================================================================
# 要求電文パラメータ値の指定
#==========================================================================
@request_data = Veritrans::Tercerog::Mdk::BankAuthorizeRequestDto.new
@request_data.service_option_type = @service_option_type.to_s
@request_data.order_id= @order_id.to_s
@request_data.amount= @payment_amount.to_s
@request_data.name1= @client_name1.to_s
@request_data.kana1= @client_kana1.to_s
@request_data.post1= @postal_code1.to_s
@request_data.post2= @postal_code2.to_s
@request_data.address1= @address.to_s
@request_data.tel_no= @telephone_number.to_s
@request_data.pay_limit= @payment_limit.to_s
@request_data.agreement_date= @agreement_date.to_s
@request_data.contents= @contents.to_s
@request_data.contents_kana= @contents_kana.to_s


#==========================================================================
# 実施
#==========================================================================
tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
@response_data = tran.execute(@request_data)

#
# 結果コード取得
#
@txn_status = @response_data.mstatus
#
# 詳細コード取得
#
@txn_result_code = @response_data.v_result_code
#
# エラーメッセージ取得
#
@error_message = @response_data.merr_msg


#==========================================================================
# 結果表示
#==========================================================================
# 成功
if "success" == @txn_status
  puts "...Transaction Successfully Complete"
  puts "[Status]: #{@txn_status}"
  puts "[Result Code]: #{@txn_result_code}"
  puts "[Order ID]: #{@response_data.order_id}"
end
# ペンディング
if "pending" == @txn_status
  puts "...Transaction Pending"
  puts "[Status]: #{@txn_status}"
  puts "[Message]: #{@error_message}"
  puts "[Result Code]: #{@txn_result_code}"
  puts "[Order ID]: #{@response_data.order_id}"
  puts "Check log file for more information"
end
# 失敗
if "failure" == @txn_status
  puts "...Transaction Failure"
  puts "[Status]: #{@txn_status}"
  puts "[Message]: #{@error_message}"
  puts "[Result Code]: #{@txn_result_code}"
  puts "[Order ID]: #{@response_data.order_id}"
  puts "Check log file for more information"
end

#puts @response_data.to_string
