# encoding: utf-8
#
# コンビニ決済 要求サンプル
#

#
# MDKへパスを通す
#
require './MdkRuby/tgMdk/lib/tg_mdk'
require './MdkRuby/tgMdk/lib/tg_mdk/mdk_dto'

#-------------------------------------------------------
# 決済方式
#-------------------------------------------------------
@service_option_type = "sej"

#-------------------------------------------------------
# 取引ID
#-------------------------------------------------------
@order_id = "dummy" + Time.now.to_i.to_s

#-------------------------------------------------------
# 支払金額
#-------------------------------------------------------
@payment_amount = "10"

#-------------------------------------------------------
# 顧客名
#-------------------------------------------------------
@name1 = "顧客"
@name2 = "氏名"

#-------------------------------------------------------
# 電話番号
# (1)決済請求（共通）：
# 電話番号の上２桁が次の場合、successを返します。
# "09", "08", "07", "06", "05"
# 上記以外の場合、failureを返します。
#
# (2)決済取消（Other）：
# 電話番号の上2桁が次の場合、successを返します。
# "06", "05"
# 上記以外の場合、failureを返します。
#-------------------------------------------------------
@tel_no = "0523456789"

#-------------------------------------------------------
# 住所
#-------------------------------------------------------
@address = "東京都港区１－６－１"

#-------------------------------------------------------
# 支払期限
#-------------------------------------------------------
@payment_limit = (Time.now + 24*60*60*5).strftime("%Y%m%d").to_s

#-------------------------------------------------------
# 成約日
#-------------------------------------------------------
@agreement_date = (Time.now - 24*60*60*1).strftime("%Y%m%d").to_s

#-------------------------------------------------------
# 請求内容
#-------------------------------------------------------
@contents = "表示インフォメーション"

#-------------------------------------------------------
# 請求内容カナ
#-------------------------------------------------------
@contents_kana = "ヒョウジインフォメーションカナ"


#==========================================================================
# 要求電文パラメータ値の指定
#==========================================================================
@request_data = Veritrans::Tercerog::Mdk::CvsAuthorizeRequestDto.new
@request_data.service_option_type = @service_option_type.to_s
@request_data.order_id= @order_id.to_s
@request_data.amount= @payment_amount.to_s
@request_data.name1= @name1.to_s
@request_data.name2= @name2.to_s
@request_data.tel_no= @tel_no.to_s
@request_data.pay_limit= @payment_limit.to_s
@request_data.payment_type = "0"


#==========================================================================
# 実施
#==========================================================================
tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
@response_data = tran.execute(@request_data)

#
# 結果コード取得
#
@txn_status = @response_data.mstatus
#
# 詳細コード取得
#
@txn_result_code = @response_data.v_result_code
#
# エラーメッセージ取得
#
@error_message = @response_data.merr_msg


#==========================================================================
# 結果表示
#==========================================================================
# 成功
if "success" == @txn_status
  puts "...Transaction Successfully Complete"
  puts "[Status]: #{@txn_status}"
  puts "[Result Code]: #{@txn_result_code}"
  puts "[Order ID]: #{@response_data.order_id}"
  puts "[Receipt Number]: #{@response_data.receipt_no}"
  puts "[URL]: #{@response_data.haraikomi_url}"
end
# ペンディング
if "pending" == @txn_status
  puts "...Transaction Pending"
  puts "[Status]: #{@txn_status}"
  puts "[Message]: #{@error_message}"
  puts "[Result Code]: #{@txn_result_code}"
  puts "[Order ID]: #{@response_data.order_id}"
  puts "Check log file for more information"
end
# 失敗
if "failure" == @txn_status
  puts "...Transaction Failure"
  puts "[Status]: #{@txn_status}"
  puts "[Message]: #{@error_message}"
  puts "[Result Code]: #{@txn_result_code}"
  puts "[Order ID]: #{@response_data.order_id}"
  puts "Check log file for more information"
end

#puts @response_data.to_string
