# encoding: utf-8
#
# クレジットカード決済(本人認証) 認可要求サンプル
#

#
# MDKへパスを通す
#
require './MdkRuby/tgMdk/lib/tg_mdk'
require './MdkRuby/tgMdk/lib/tg_mdk/mdk_dto'

#-------------------------------------------------------
# オプションタイプ
# 1. 本人認証サービスのみ                    : mpi-none
# 2. 完全認証                                : mpi-complete
# 3. 通常認証（カード会社リスク負担）        : mpi-company
# 4. 通常認証（カード会社、加盟店リスク負担）: mpi-merchant
#-------------------------------------------------------
@service_option_type = "mpi-company"

#-------------------------------------------------------
# 取引ID
#-------------------------------------------------------
@order_id = "dummy" + Time.now.to_i.to_s

#-------------------------------------------------------
# 決済金額
#-------------------------------------------------------
@payment_amount = "10"

#-------------------------------------------------------
# トークン
#-------------------------------------------------------
@token = "0a812412-682c-4dad-8a5d-720caf23bca0";

#-------------------------------------------------------
# カード番号
#-------------------------------------------------------
#@card_number = "4111-1111-1111-1111"

#-------------------------------------------------------
# カード有効期限
#-------------------------------------------------------
#@card_expire = "12/16"

#-------------------------------------------------------
# HTTP User-Agent（消費者ブラウザ）
# （実際はアプリケーションサーバから取得）
#-------------------------------------------------------
@http_user_agent = "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1)"

#-------------------------------------------------------
# HTTP Accept（消費者ブラウザ）
# （実際はアプリケーションサーバから取得）
#-------------------------------------------------------
@http_accept = "text/*;q=0.3, text/html;q=0.7"

#-------------------------------------------------------
# デバイスチャネル
# 02:ブラウザベース
#-------------------------------------------------------
@device_channel = "02"

#-------------------------------------------------------
# カード保有者名
#-------------------------------------------------------
@cardholder_name = "cardholderName"


#==========================================================================
# 要求電文パラメータ値の指定
#==========================================================================
@request_data = Veritrans::Tercerog::Mdk::MpiAuthorizeRequestDto.new
@request_data.service_option_type = @service_option_type.to_s
@request_data.order_id= @order_id.to_s
@request_data.amount= @payment_amount.to_s
@request_data.token = @token.to_s
#@request_data.card_number = @card_number.to_s
#@request_data.card_expire = @card_expire.to_s
@request_data.http_user_agent = @http_user_agent.to_s
@request_data.http_accept = @http_accept.to_s
@request_data.device_channel = @device_channel.to_s
@request_data.cardholder_name = @cardholder_name.to_s

#==========================================================================
# 実施
#==========================================================================
tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
@response_data = tran.execute(@request_data)

#
# 結果コード取得
#
@txn_status = @response_data.mstatus
#
# 詳細コード取得
#
@txn_result_code = @response_data.v_result_code
#
# エラーメッセージ取得
#
@error_message = @response_data.merr_msg


#==========================================================================
# 結果表示
#==========================================================================
# 成功
if "success" == @txn_status
  puts "...Transaction Successfully Complete"
  puts "[Status]: #{@txn_status}"
  puts "[Result Code]: #{@txn_result_code}"
  puts "[Order ID]: #{@response_data.order_id}"
  puts "[MPI Transaction Type]: #{@response_data.mpi_transactiontype}"
end
# ペンディング
if "pending" == @txn_status
  puts "...Transaction Pending"
  puts "[Status]: #{@txn_status}"
  puts "[Message]: #{@error_message}"
  puts "[Result Code]: #{@txn_result_code}"
  puts "[Order ID]: #{@response_data.order_id}"
  puts "[MPI Transaction Type]: #{@response_data.mpi_transactiontype}"
  puts "Check log file for more information"
end
# 失敗
if "failure" == @txn_status
  puts "...Transaction Failure"
  puts "[Status]: #{@txn_status}"
  puts "[Message]: #{@error_message}"
  puts "[Result Code]: #{@txn_result_code}"
  puts "[Order ID]: #{@response_data.order_id}"
  puts "[MPI Transaction Type]: #{@response_data.mpi_transactiontype}"
  puts "Check log file for more information"
end

#puts @response_data.to_string
