# -*- encoding: utf-8 -*-
class ApplicationController < ActionController::Base
  helper :all
  protect_from_forgery

  #
  # 出力をUTF-8からShift_JISに変更して出力する。
  #
  def to_sjis
    response.headers["Content-Type"] = "text/html; charset=Shift_JIS"
    response.body = _convert_charset(response.body, '-Ws')
  end

  #
  # 入力をShift_JISからUTF-8に変更して取得する。
  #
  def to_utf8
    data = params ||= nil
    params = _convert_charset(data, '-Sw')
  end

  #
  # 文字列のコンバート処理
  #
  def _convert_charset(data, nkf_opt='')
    if data.is_a?(String)
      require 'nkf'
      return NKF.nkf('-m0 -x '+nkf_opt, data)
    elsif data.is_a?(Hash)
      data.each do |key,val|
        data[key] = _convert_charset(val, nkf_opt)
      end
      return data
    elsif String(data.class) == "NilClass"
      return nil
    else
      return data
    end
  end

  private

  #
  # Decode string using Base64 of Ruby
  #
  def decode64_str(str)
    Base64.decode64(str.gsub('-','/').gsub('_','+').gsub('*','='))
  end

  #
  # Railsアプリケーションのルートを取得する。
  #
  def rails_root
    return Rails.root
  end

  #
  # "env4sample.yml"の内容をロードする。
  #
  def loadEnv4sample
    require 'yaml'
    return YAML.load_file("#{rails_root}/config/env4sample.yml")
  end
end
