# -*- encoding: utf-8 -*-
class Web::Alipay::AuthorizeController < ApplicationController
  include MdkValidation
  before_action :set_init
  skip_before_action :verify_authenticity_token, :only => [:authorize_result]

  #-------------------------------------------------------------------------
  # 入力フォーム初期表示
  #-------------------------------------------------------------------------
  def index
    @currency = nil unless instance_variable_defined?(:@currency)
  end

  #-------------------------------------------------------------------------
  # Alipay決済 与信要求サンプル
  #-------------------------------------------------------------------------
  def execute
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # 取引ID
    @order_id = params[:order_id]
    # 支払金額
    @amount = params[:amount]
    # 通貨
    @currency = params[:currency]
    # 決済種別
    @pay_type = params[:pay_type]
    # ユーザ識別コード
    @identity_code = params[:identityCode]
    # 商品名
    @commodityName = params[:commodityName]
    # 商品詳細
    @commodityDescription = params[:commodityDescription]
    # 商品ID
    @commodityId = params[:commodityId]
    # 決済完了時URL
    @successUrl = params[:successUrl]
    # 決済エラー時URL
    @errorUrl = params[:errorUrl]
    # レスポンスタイプ
    @responseType = params[:responseType]


    #-------------------------------------------------------------------------
    # 取引ID更新の場合の処理
    #-------------------------------------------------------------------------
    unless params[:update_id].blank?
      @order_id = "dummy" + Time.now.to_i.to_s
      render :action => "index"
      return
    end

    @err_msg = validate_alipay_auth
    unless @err_msg.blank?
      render :action => :index
      return
    end


    #-------------------------------------------------------------------------
    # 要求DTOを生成し、値を設定します。
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::AlipayAuthorizeRequestDto.new
    req.order_id = @order_id.to_s
    req.amount = @amount.to_s
    req.currency = @currency.to_s
    req.pay_type = @pay_type.to_s
    req.identity_code = @identity_code.to_s
    req.commodity_name = @commodityName.to_s
    req.commodity_description = @commodityDescription.to_s
    req.commodity_id = @commodityId.to_s
    req.success_url = @successUrl.to_s
    req.error_url = @errorUrl.to_s
    req.response_type = @responseType.to_s

    #-------------------------------------------------------------------------
    # コマンドを実行し、応答DTOを取得します。
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)


    #--------------------------------------------------------------------------
    # 結果画面に表示します。
    #--------------------------------------------------------------------------
    @response = res
    @result_order_id = res.order_id
    @mstatus = res.mstatus
    @v_result_code = res.v_result_code
    @merr_msg = res.merr_msg
    if @pay_type == "1" || @pay_type == "2"
      @cust_txn = res.cust_txn
      @center_trade_id = res.center_trade_id
    end
    if @pay_type == "1"
      @pay_time_jp = res.pay_time_jp
      @pay_time_cn = res.pay_time_cn
      @buyer_charged_amount_cny = res.buyer_charged_amount_cny
    elsif @pay_type == "2"
      @qr_code = res.qr_code
      @qr_code_img_url = res.qr_code_img_url
      @qr_code_small_img_url = res.qr_code_small_img_url
      @qr_code_large_img_url = res.qr_code_large_img_url
    end
  end

  #-------------------------------------------------------------------------
  # 支払いサイトからサンプル応答
  #-------------------------------------------------------------------------
  def authorize_result

    @mstatus = params[:mstatus]
    @v_result_code = params[:vResultCode]
    @merr_msg = params[:merrMsg]
    @result_order_id = params[:orderId]
    @cust_txn = params[:custTxn]
    @center_trade_id = params[:centerTradeId]
    @settlement_amt = params[:settleAmount]
    @settlement_currency = params[:settleCurrency]

    if params[:authInfo].nil?
      return
    end

    keys = params[:authInfo].split("-")
    @auth = "1"
    if keys.size != 3
      @auth = "0"
    else
      # decode64_str - private method in application controller
      merchant_cc_id = decode64_str(keys[0])
      gmnow  = decode64_str(keys[1])
      received_hash = decode64_str(keys[2])
      merchant_secret_key = Veritrans::Tercerog::Mdk::MdkConfig.instance.merchant_secret_key.strip

      if !received_hash.eql?(Veritrans::Tercerog::Mdk::MdkUtils::mdk_digest(merchant_cc_id + gmnow + merchant_secret_key))
        @auth = "0"
      end
    end
  end

  private

  def set_init
    @order_id = "dummy" + Time.now.to_i.to_s
    @amount = params[:price].to_s || params[:price]

    #yaml形式のconfig.ymlファイルを読み込む
    config = loadEnv4sample
    @success_url = config["Alipay"]["success_url"]
    @error_url  = config["Alipay"]["error_url"]

    if params[:commodityName]
      @commodity_name = params[:commodityName]
    else
      @commodity_name = "新製品"
    end
    if params[:commodityDescription]
      @commodity_description = params[:commodityDescription]
    else
      @commodity_description = "新製品詳細"
    end
  end
end
