# -*- encoding: utf-8 -*-
class Web::Carrier::AbstractAuthorizeController < ApplicationController

  # set_dummy_request を実行する
  # after_action では render の後に実行されるため
  before_action :set_dummy_request

  #-------------------------------------------------------------------------
  # 入力フォーム初期表示
  #-------------------------------------------------------------------------
  def index
    @order_id = "dummy" + Time.now.to_i.to_s
    @amount = params[:amount].to_s
    @service_option_type ||= ''

    #yaml形式のconfig.ymlファイルを読み込む
    config = loadEnv4sample

    suffix = get_config_suffix

    #各種URLを取得
    @success_url = config["Carrier"]["success_url"+suffix]
    @cancel_url  = config["Carrier"]["cancel_url"+suffix]
    @error_url   = config["Carrier"]["error_url"+suffix]
    @push_url    = config["Carrier"]["push_url"+suffix]

    set_my_default
  end

  #-------------------------------------------------------------------------
  # before_action で実行されるメソッド
  def set_dummy_request
    # ダミーモード判定
    mdk_config = Veritrans::Tercerog::Mdk::MdkConfig.instance
    @dummy_request = mdk_config[:DUMMY_REQUEST]
  end

  #-------------------------------------------------------------------------
  # キャリア決済 与信要求サンプル
  #-------------------------------------------------------------------------
  def execute
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # 取引ID
    @order_id = params[:order_id]
    # 支払金額
    @amount = params[:amount]
    # サービスオプションタイプ(キャリアの種類)を取得
    @service_option_type = params[:service_option_type]
    # 課金種別の取得
    @accounting_type = params[:accounting_type]
    # 与信方法
    @with_capture = params[:with_capture]
    if @with_capture == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_AUTH_WITH_CAPTURE
      @is_with_capture = Veritrans::Tercerog::Mdk::MdkConst::TRUE
    else
      @is_with_capture = Veritrans::Tercerog::Mdk::MdkConst::FALSE
    end
    # 初回課金年月日の取得
    @mp_first_date = params[:mp_first_date]
    # 継続課金日の取得
    @mp_day = params[:mp_day]

    #端末種別
    @terminal_kind = params[:terminal_kind]
    #商品タイプ
    @item_type = params[:item_type]
    #3Dセキュア
    @d3_flag = params[:d3_flag]
    #商品番号
    @item_id = params[:item_id]
    #商品情報
    @item_info = params[:item_info]
    #決済完了時URL
    @success_url = params[:success_url]
    #決済キャンセル時URL
    @cancel_url = params[:cancel_url]
    #決済エラー時URL
    @error_url = params[:error_url]
    #プッシュURL
    @push_url = params[:push_url]
    #フレッツエリア
    @flets_area = params[:flets_area]
    #auIDログインフラグ
    @login_au_id = params[:login_au_id]
    if @login_au_id == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_AU_ID_LOGIN
      @login_au_id = Veritrans::Tercerog::Mdk::MdkConst::TRUE
    else
      @login_au_id = Veritrans::Tercerog::Mdk::MdkConst::FALSE
    end

    #OpenID
    @open_id = params[:open_id]

    #-------------------------------------------------------------------------
    # 取引ID更新の場合の処理
    #-------------------------------------------------------------------------
    unless params[:update_id].blank?
      @order_id = "dummy" + Time.now.to_i.to_s
      render :action => "index"
      return
    end

    #-------------------------------------------------------------------------
    #  入力パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = ""
    if @order_id.nil? || @order_id.empty?
      @error_message = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font><br/><br/>"
      @order_id = "dummy" + Time.now.to_i.to_s
      render :action => "index"
      return
    end
    if @amount.nil? || @amount.empty?
       unless @accounting_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_ONDEMAND
        @error_message = "<font color='#ff0000'><b>必須項目：決済金額が指定されていません</b></font><br/><br/>"
        render :action => "index"
        return
       end
    end
    if @accounting_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_MONTHLY
      unless @service_option_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_SB_MATOMETE
        if @mp_day.empty?
          @error_message = "<font color='#ff0000'><b>必須項目：継続課金日が指定されていません</b></font><br/><br/>"
          render :action => "index"
          return
        end
        if @mp_first_date.empty?
          @error_message = "<font color='#ff0000'><b>必須項目：初回課金年月日が指定されていません</b></font><br/><br/>"
          render :action => "index"
          return
        end
      end
    end
    # ダミーモード判定
    unless @push_url.nil? || @push_url.empty?
      mdk_config = Veritrans::Tercerog::Mdk::MdkConfig.instance
      unless mdk_config[:DUMMY_REQUEST] == Veritrans::Tercerog::Mdk::MdkConst::DUMMY_MODE_TRUE
          @error_message = "<font color='#ff0000'><b>プッシュURLはダミーモードのときにのみ指定可能です</b></font><br/><br/>"
          render :action => "index"
          return
      end
    end

    # yaml形式のconfig.ymlファイルを読み込む
    config = loadEnv4sample

    suffix = get_config_suffix
    if @success_url.nil? || @success_url.empty?
      @success_url = config["Carrier"]["success_url"+suffix]
    end
    if @cancel_url.nil? || @cancel_url.empty?
      @cancel_url  = config["Carrier"]["cancel_url"+suffix]
    end
    if @error_url.nil? || @error_url.empty?
      @error_url   = config["Carrier"]["error_url"+suffix]
    end

    #-------------------------------------------------------------------------
    # 要求電文パラメータ値の指定
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::CarrierAuthorizeRequestDto.new
    req.service_option_type = @service_option_type.to_s
    req.order_id = @order_id.to_s
    req.amount = @amount.to_s
    req.accounting_type = @accounting_type.to_s
    # with_capture フラグは都度のとき、また、ソフトバンクまとめて支払い（A）は true 固定
    unless @accounting_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_MONTHLY || @accounting_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_ONDEMAND
      if @service_option_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_SB_MATOMETE
        req.with_capture = Veritrans::Tercerog::Mdk::MdkConst::TRUE
      else
        req.with_capture = @is_with_capture.to_s
      end
    end
    # 3Dセキュアフラグはソフトバンクまとめて支払い（B）のみ
    if @service_option_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_SB_KTAI
      req.d3_flag = @d3_flag.to_s
    end
    # UIDはS!まとめて支払いのみ
    if @service_option_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_S_BIKKURI
      uid = request.env['HTTP_X_JPHONE_UID']
      # ダミーモードのときは適当な値を設定
      mdk_config = Veritrans::Tercerog::Mdk::MdkConfig.instance
      if mdk_config[:DUMMY_REQUEST] == Veritrans::Tercerog::Mdk::MdkConst::DUMMY_MODE_TRUE
         uid = "dummyUID" if uid.nil?
      end
      req.sb_uid = uid.to_s unless uid.nil?
      puts "===== UID[" + (uid.nil? ? "nil":uid.to_s) + "]====="
    end
    # フレッツエリアはフレッツまとめて支払いのみ
    if @service_option_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_FLETS
      req.flets_area = @flets_area.to_s
    end
    # auIDログインフラグはauかんたん決済のみ
    if @service_option_type == Veritrans::Tercerog::Mdk::MdkConst::CARRIER_AU
      req.login_au_id = @login_au_id.to_s
    end

    req.mp_first_date = @mp_first_date.to_s
    req.mp_day = @mp_day.to_s
    req.terminal_kind = @terminal_kind.to_s
    req.item_type = @item_type.to_s
    req.item_id = @item_id.to_s
    req.item_info = @item_info.to_s
    req.success_url = @success_url.to_s
    req.cancel_url = @cancel_url.to_s
    req.error_url = @error_url.to_s
    req.push_url = @push_url.to_s unless @push_url.nil?
    req.open_id = @open_id.to_s unless @open_id.nil?

    #-------------------------------------------------------------------------
    #  実施
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)
    @response_data = res
    @request_data = req

    #--------------------------------------------------------------------------
    #レスポンスの取得
    #--------------------------------------------------------------------------

    # ログ
    puts "===== Debug Log ====="
    puts "Carrier[" + @service_option_type + "] : vResultCode=" + @response_data.v_result_code

    @no_header_footer = "false"
    if @response_data.mstatus.to_s == Veritrans::Tercerog::Mdk::MdkConst::SUCCESS
      @redirect_html = res.response_contents
      if !@redirect_html.nil? && !@redirect_html.empty?
        # redirect コンテンツを返す場合、view で header/footer を表示しない
        #@no_header_footer = is_no_header_footer
        @no_header_footer = "true"
      elsif !res.redirect_url.nil?
        redirect_to res.redirect_url, :status => 301
      end
    else
      @redirect_html = ""
    end

    @v_result_code = res.v_result_code
    @result_order_id = res.order_id
    @mstatus = res.mstatus
    @merr_msg = res.merr_msg
  end

end
