# -*- encoding: utf-8 -*-
class Web::Em::AuthorizeController < ApplicationController

  #-------------------------------------------------------------------------
  # 入力フォーム初期表示
  #-------------------------------------------------------------------------
  def index
    @order_id = "dummy" + Time.now.to_i.to_s
    @amount = params[:price].to_s
  end

  #-------------------------------------------------------------------------
  # 電子マネー決済要求サンプル
  #-------------------------------------------------------------------------
  def execute
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # 決済方式
    @service_option_type = params[:service_option_type]
    # 取引ID
    @order_id = params[:order_id]
    # 決済金額
    @amount = params[:amount]
    # メールアドレス
    @mail_address = params[:mail_address]
    # 決済期限
    @settlement_limit = params[:settlement_limit]
    # 支払取消期限
    @cancel_limit = params[:cancel_limit]
    # 取引種別
    @transaction_kind = params[:transaction_kind]
    # ユーザID
    @user_id = params[:user_id]
    # 決済アプリケーション起動URL
    @app_url ||= ''


    #-------------------------------------------------------------------------
    # 取引ID更新の場合の処理
    #-------------------------------------------------------------------------
    unless params[:update_id].blank?
      @order_id = "dummy" + Time.now.to_i.to_s
      render :action => "index"
      return
    end


    #-------------------------------------------------------------------------
    # 必須パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = ""
    if @order_id == ""
      @error_message = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font><br/><br/>"
      render :action => "index"
      return
    end
    if @amount == ""
      @error_message = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font><br/><br/>"
      render :action => "index"
      return
    end
    if @settlement_limit == ""
      if @service_option_type != "edy-pc" && @service_option_type != "edy-direct" && @service_option_type != "tcc-redirect"
        @error_message = "<font color='#ff0000'><b>必須項目：決済期限が指定されていません</b></font><br/><br/>"
        render :action => "index"
        return
      end
    end
    if @cancel_limit == ""
      if @service_option_type == "waon-pc" || @service_option_type == "waon-mobile"
        @error_message = "<font color='#ff0000'><b>必須項目：支払取消期限が指定されていません</b></font><br/><br/>"
        render :action => "index"
        return
      end
    end
    if @mail_address == ""
      if
        @service_option_type != "edy-pc" and
          @service_option_type != "edy-direct" and
          @service_option_type != "suica-mobile-app" and
          @service_option_type != "suica-pc-app" and
          @service_option_type != "tcc-redirect"
        @error_message = "<font color='#ff0000'><b>必須項目：メールアドレスが指定されていません</b></font><br/><br/>"
        render :action => "index"
        return
      end
    end

    if @service_option_type == "tcc-redirect"
      if @user_id == ""
        @error_message = "<font color='#ff0000'><b>必須項目：ユーザIDが指定されていません</b></font><br/><br/>"
        render :action => "index"
        return
      end
    else
      if @user_id != ""
        @error_message = "<font color='#ff0000'><b>ユーザIDは指定できません</b></font><br/><br/>"
        render :action => "index"
        return
      end
    end


    #-------------------------------------------------------------------------
    # 要求DTOを生成し、値を設定します。
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::EmAuthorizeRequestDto.new
    req.service_option_type = @service_option_type
    req.order_id = @order_id.to_s
    req.amount = @amount.to_s
    req.settlement_limit =  @settlement_limit.to_s

    if @service_option_type != "edy-pc" and
       @service_option_type != "edy-direct" and
       @service_option_type != "suica-mobile-app" and
       @service_option_type != "suica-pc-app" and
       @service_option_type != "tcc-redirect"
      req.mail_addr = @mail_address.to_s
    end

    if /^suica.*/m =~  @service_option_type
      # Suica決済の場合
      req.screen_title =  "SampleTitle"

    elsif @service_option_type  == "waon-pc"
      # WAON PaSoRi決済の場合
      req.cancel_limit = @settlement_limit.to_s

      # サンプルのためダミーURLを設定
      req.success_url = "http://127.0.0.1/web/PaymentMethodSelect?status=success"
      req.failure_url = "http://127.0.0.1/web/PaymentMethodSelect?status=failure"
      req.cancel_url = "http://127.0.0.1/web/PaymentMethodSelect?status=cancel"

    elsif @service_option_type == "waon-mobile"
      # WAON モバイルアプリ決済の場合
      req.cancel_limit = @settlement_limit.to_s

    elsif @service_option_type == "tcc-redirect"
      # nanaco決済の場合
      req.transaction_kind = "02"  # 02:電子マネー固定
      req.user_id = @user_id;

      #yaml形式のconfig.ymlファイルを読み込む
      config = loadEnv4sample
      req.complete_notice_url = config["EM"]["tcc.complete_notice_url"].to_s
    end

    #-------------------------------------------------------------------------
    # コマンドを実行し、応答DTOを取得します。
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)

    if "success" == res.mstatus && @service_option_type == "tcc-redirect"
      # nanaco決済が成功した場合はリダイレクト
      redirect_to res.app_url, :status => 301

    else
      #--------------------------------------------------------------------------
      # 結果画面に表示します。
      #--------------------------------------------------------------------------
      @result_order_id = res.order_id
      @mstatus = res.mstatus
      @v_result_code = res.v_result_code
      @merr_msg = res.merr_msg

      @receipt_no = res.receipt_no
      @app_url = res.app_url
    end
  end
end
