# -*- encoding: utf-8 -*-
class Web::Masterpass::AuthorizeController < ApplicationController

  # set_dummy_request を実行する
  # after_action では render の後に実行されるため
  before_action :set_dummy_request

  #-------------------------------------------------------------------------
  # 入力フォーム初期表示
  #-------------------------------------------------------------------------
  def index
    @order_id = params[:orderId].to_s
    @card_number = params[:cardNumber].to_s
    @shipping_name = params[:shippingName].to_s
    @shipping_phone = params[:shippingPhone].to_s
    @shipping_city = params[:shippingCity].to_s
    @shipping_country = params[:shippingCountry].to_s
    @shipping_country_sub_division = params[:shippingCountrySubdivision].to_s
    @shipping_address1 = params[:shippingAddress1].to_s
    @shipping_address2 = params[:shippingAddress2].to_s
    @shipping_address3 = params[:shippingAddress3].to_s
    @shipping_postal_code = params[:shippingPostalCode].to_s
    @amount    = params[:amount].to_s
  end

  #-------------------------------------------------------------------------
  # before_action で実行されるメソッド
  def set_dummy_request
    # ダミーモード判定
    mdk_config = Veritrans::Tercerog::Mdk::MdkConfig.instance
    @dummy_request = mdk_config[:DUMMY_REQUEST]
  end

  #-------------------------------------------------------------------------
  # MasterPass 与信要求サンプル
  #-------------------------------------------------------------------------
  def execute
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # 取引ID
    @order_id = params[:order_id]
    # 支払金額
    @amount = params[:amount]
    # 与信方法
    @with_capture = params[:with_capture]

    #-------------------------------------------------------------------------
    #  入力パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = ""
    if @order_id.nil? || @order_id.empty?
      @error_message = "<font color='#ff0000'><b>Unset Order Id<br>(必須項目：取引IDが指定されていません)</b></font><br/><br/>"
      @order_id = "dummy" + Time.now.to_i.to_s
      render :action => "index"
      return
    end
    if @amount.nil? || @amount.empty?
      @error_message = "<font color='#ff0000'><b>Unset Amount<br>(必須項目：金額が指定されていません)</b></font><br/><br/>"
      render :action => "index"
      return
    end

    #-------------------------------------------------------------------------
    # 要求電文パラメータ値の指定
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::MasterpassAuthorizeRequestDto.new
    req.order_id = @order_id.to_s
    req.amount = @amount.to_s
    req.with_capture = @with_capture.to_s

    #-------------------------------------------------------------------------
    #  実施
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)
    @response_data = res
    @request_data = req

    #--------------------------------------------------------------------------
    #レスポンスの取得
    #--------------------------------------------------------------------------

    # ログ
    puts "===== Debug Log ====="
    puts "vResultCode=" + @response_data.v_result_code

    @no_header_footer = "false"

    @v_result_code = res.v_result_code
    @result_order_id = res.order_id
    @mstatus = res.mstatus
    @merr_msg = res.merr_msg
    @authorize_datetime = res.authorize_datetime
    @auth_code = res.auth_code
  end

end
