# -*- encoding: utf-8 -*-
class Web::Paynowid::Card::AndEntryController < ApplicationController

  #-------------------------------------------------------------------------
  # 入力フォーム初期表示
  #-------------------------------------------------------------------------
  def index
    @order_id = "dummy" + Time.now.to_i.to_s
    load_token_api_info
  end

  #-------------------------------------------------------------------------
  # カード決済実行サンプル
  #-------------------------------------------------------------------------
  def execute
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # 与信方法
    @with_capture = params[:with_capture]
    # 取引ID
    @order_id = params[:order_id]
    # 金額
    @amount = params[:amount]
    # 支払方法
    @jpo1 = params[:jpo1]
    # 支払回数
    @jpo2 = params[:jpo2]
    # トークン
    @token = params[:token]

    # 会員ID
    @account_id = params[:account_id]

    # 課金グループID
    @group_id = params[:group_id]
    # 課金開始日
    @start_date = params[:start_date]
    # 課金終了日
    @end_date = params[:end_date]
    # 都度／初回課金金額
    @one_time_amount = params[:one_time_amount]
    # 継続課金金額
    @recurring_amount = params[:recurring_amount]


    #-------------------------------------------------------------------------
    # 取引ID更新の場合の処理
    #-------------------------------------------------------------------------
    unless params[:update_id].blank?
      @order_id = "dummy" + Time.now.to_i.to_s
      load_token_api_info
      render :action => "index"
      return
    end


    #-------------------------------------------------------------------------
    # 必須パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = nil
    if @order_id.nil? || @order_id.empty?
      # 取引ID
      @error_message = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>"

    elsif @amount.nil? || @amount.empty?
      # 金額
      @error_message = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>"

    end
    unless @error_message.nil?
      # エラーが存在する場合は入力画面に戻る。
      render :action => "index"
      return
    end


    #-------------------------------------------------------------------------
    # 要求DTOを生成し、値を設定します。
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::CardAuthorizeRequestDto.new
    req.order_id = @order_id.to_s
    req.amount = @amount.to_s
    req.token = @token.to_s

    if @jpo1 == "10" || @jpo1 == "80"
      req.jpo = @jpo1.to_s
    elsif @jpo1 == "61" && !@jpo2.empty?
      req.jpo = "#{@jpo1}C#{@jpo2}"
    end

    if @with_capture == "1"
      req.with_capture = "true"
    end

    req.account_id = @account_id.to_s
    req.group_id = @group_id.to_s
    req.start_date = @start_date.to_s
    req.end_date = @end_date.to_s
    req.one_time_amount = @one_time_amount.to_s
    req.recurring_amount = @recurring_amount.to_s


    #-------------------------------------------------------------------------
    # コマンドを実行し、応答DTOを取得します。
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)


    #--------------------------------------------------------------------------
    # 結果画面に表示します。
    #--------------------------------------------------------------------------
    @order_id = res.order_id
    @mstatus = res.mstatus
    @v_result_code = res.v_result_code
    @merr_msg = res.merr_msg

    if !res.pay_now_id_response.nil?
      @pay_now_id_status = res.pay_now_id_response.status
    end
  end

  private

  #-------------------------------------------------------------------------
  # MDKトークン設定情報を読み込む。
  #-------------------------------------------------------------------------
  def load_token_api_info
    config = loadEnv4sample
    @token_api_key = config["Token"]["token_api_key"].to_s
    @token_api_url = config["Token"]["token_api_url"].to_s
    if @token_api_url.blank?
      mdk_config = Veritrans::Tercerog::Mdk::MdkConfig.instance
      uri = URI.parse(mdk_config[:HOST_URL])
      @token_api_url = uri.to_s + "/4gtoken"
    end
  end

end
