# -*- encoding: utf-8 -*-
class Web::Paynowid::Card::ManageController < ApplicationController

  SESSION_KEY_CARD_SELECT_ITEMS = "card_select_items".freeze

  #-------------------------------------------------------------------------
  # 入力フォーム初期表示
  #-------------------------------------------------------------------------
  def index
    @card_select_items = create_card_select_items_for_form(nil)
    session[SESSION_KEY_CARD_SELECT_ITEMS] = @card_select_items
    @card_select = ''

    load_token_api_info
  end

  #-------------------------------------------------------------------------
  # 会員カード管理サンプル
  #-------------------------------------------------------------------------
  def execute
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # 処理モード
    @exec_mode = params[:exec_mode]
    # 会員ID
    @account_id = params[:account_id]
    # カード選択
    @card_select = params[:card_select]
    # トークン
    @token = params[:token]

    # セッションからカード情報を取得
    @card_select_items = session[SESSION_KEY_CARD_SELECT_ITEMS]

    if !params[:get_card_info].blank?
      # カード情報取得処理の場合
      get_card_info

    elsif !params[:delete_card_info].blank?
      # カード情報削除処理の場合
      delete_card_info

    else
      # カード情報登録処理の場合
      register_card_info
    end
  end

  private

  #-------------------------------------------------------------------------
  # カード情報取得サンプル
  #-------------------------------------------------------------------------
  def get_card_info
    #-------------------------------------------------------------------------
    # 必須パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = nil
    if @account_id.nil? || @account_id.empty?
      # 会員ID
      @error_message = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>"
    end

    unless @error_message.nil?
      # エラーが存在する場合は入力画面に戻る。
      load_token_api_info
      render :action => "index"
      return
    end


    #-------------------------------------------------------------------------
    # 要求DTOを生成し、値を設定します。
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::CardInfoGetRequestDto.new
    req.account_id = @account_id.to_s


    #-------------------------------------------------------------------------
    # コマンドを実行し、応答DTOを取得します。
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)


    #--------------------------------------------------------------------------
    # 結果画面に表示します。
    #--------------------------------------------------------------------------
    @mstatus = res.mstatus
    if @mstatus == "success"
      # 成功の場合は入力画面に遷移
      @card_select_items = create_card_select_items_for_form(res.pay_now_id_response.account.card_info)
      session[SESSION_KEY_CARD_SELECT_ITEMS] = @card_select_items
      load_token_api_info
      render :action => "index"

    else
      # それ以外の場合は結果画面に遷移
      @v_result_code = res.v_result_code
      @merr_msg = res.merr_msg

      if !res.pay_now_id_response.nil?
        @pay_now_id_proc_id = res.pay_now_id_response.process_id
        @pay_now_id_status = res.pay_now_id_response.status
      end
    end
  end

  #-------------------------------------------------------------------------
  # カード情報登録サンプル
  #-------------------------------------------------------------------------
  def register_card_info
    #-------------------------------------------------------------------------
    # 必須パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = nil
    if @account_id.nil? || @account_id.empty?
      # 会員ID
      @error_message = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>"
    end

    unless @error_message.nil?
      # エラーが存在する場合は入力画面に戻る。
      load_token_api_info
      render :action => "index"
      return
    end


    #-------------------------------------------------------------------------
    # 要求DTOを生成し、値を設定します。
    #-------------------------------------------------------------------------
    if @card_select.nil? || @card_select.blank?
      # カードが選択されていない場合は登録処理を行う。
      req = Veritrans::Tercerog::Mdk::CardInfoAddRequestDto.new
    elsif
      # カードが選択されている場合は更新処理を行う。
      req = Veritrans::Tercerog::Mdk::CardInfoUpdateRequestDto.new
      req.card_id = @card_select.to_s
    end
    req.account_id = @account_id.to_s
    req.token = @token.to_s


    #-------------------------------------------------------------------------
    # コマンドを実行し、応答DTOを取得します。
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)


    #--------------------------------------------------------------------------
    # 結果画面に表示します。
    #--------------------------------------------------------------------------
    @v_result_code = res.v_result_code
    @merr_msg = res.merr_msg

    if !res.pay_now_id_response.nil?
      @pay_now_id_proc_id = res.pay_now_id_response.process_id
      @pay_now_id_status = res.pay_now_id_response.status
    end
  end

  #-------------------------------------------------------------------------
  # カード情報削除サンプル
  #-------------------------------------------------------------------------
  def delete_card_info
    #-------------------------------------------------------------------------
    # 必須パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = nil
    if @account_id.nil? || @account_id.empty?
      # 会員ID
      @error_message = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>"

    elsif @card_select.nil? || @card_select.empty?
      # カード選択
      @error_message = "<font color='#ff0000'><b>必須項目：削除対象カードを選択してください</b></font>"
    end

    unless @error_message.nil?
      # エラーが存在する場合は入力画面に戻る。
      load_token_api_info
      render :action => "index"
      return
    end


    #-------------------------------------------------------------------------
    # 要求DTOを生成し、値を設定します。
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::CardInfoDeleteRequestDto.new
    req.account_id = @account_id.to_s
    req.card_id = @card_select.to_s


    #-------------------------------------------------------------------------
    # コマンドを実行し、応答DTOを取得します。
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)


    #--------------------------------------------------------------------------
    # 結果画面に表示します。
    #--------------------------------------------------------------------------
    @v_result_code = res.v_result_code
    @merr_msg = res.merr_msg

    if !res.pay_now_id_response.nil?
      @pay_now_id_proc_id = res.pay_now_id_response.process_id
      @pay_now_id_status = res.pay_now_id_response.status
    end
  end

  #-------------------------------------------------------------------------
  # カード情報選択項目を生成する。
  #-------------------------------------------------------------------------
  def create_card_select_items_for_form(card_info_array)

    items = [[:"新しいカードを登録する", ""]]
    unless card_info_array.nil?
      card_info_array.each { |info|
        items << [:"#{info.card_number} : #{info.card_expire}", info.card_id]
      }
    end
    return items
  end

  #-------------------------------------------------------------------------
  # MDKトークン設定情報を読み込む。
  #-------------------------------------------------------------------------
  def load_token_api_info
    config = loadEnv4sample
    @token_api_key = config["Token"]["token_api_key"].to_s
    @token_api_url = config["Token"]["token_api_url"].to_s
    if @token_api_url.blank?
      mdk_config = Veritrans::Tercerog::Mdk::MdkConfig.instance
      uri = URI.parse(mdk_config[:HOST_URL])
      @token_api_url = uri.to_s + "/4gtoken"
    end
  end
end
