# -*- encoding: utf-8 -*-
class Web::Paynowid::Mpi::AuthorizeController < ApplicationController

  skip_before_action :verify_authenticity_token ,:only=>[:search]

  SESSION_KEY_PAYMENT_MODE = "payment_mode".freeze

  #-------------------------------------------------------------------------
  # 入力フォーム初期表示（本人認証あり）
  #-------------------------------------------------------------------------
  def index
    @order_id = "dummy" + Time.now.to_i.to_s
  end

  #-------------------------------------------------------------------------
  # カード選択サンプル（本人認証あり）
  #-------------------------------------------------------------------------
  def select
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # 会員ID
    @account_id = params[:account_id]
    # 取引ID
    @order_id = params[:order_id]
    # 金額
    @amount = params[:amount]
    # 決済種別
    @payment_mode = params[:payment_mode]
    # 与信方法
    @with_capture = params[:with_capture]
    # 選択カードインデックス
    @select_card_index ||= -1


    #-------------------------------------------------------------------------
    # 取引ID更新の場合の処理
    #-------------------------------------------------------------------------
    unless params[:update_id].blank?
      @order_id = "dummy" + Time.now.to_i.to_s
      render :action => "index"
      return
    end


    #-------------------------------------------------------------------------
    # 必須パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = nil
    if @account_id.nil? || @account_id.empty?
      # 会員ID
      @error_message = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>"

    elsif @order_id.nil? || @order_id.empty?
      # 取引ID
      @error_message = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>"

    elsif @amount.nil? || @amount.empty?
      # 金額
      @error_message = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>"
    end

    unless @error_message.nil?
      # エラーが存在する場合は入力画面に戻る。
      render :action => "index"
      return
    end


    #-------------------------------------------------------------------------
    # 要求DTOを生成し、値を設定します。
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::CardInfoGetRequestDto.new
    req.account_id = @account_id.to_s


    #-------------------------------------------------------------------------
    # コマンドを実行し、応答DTOを取得します。
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)


    #--------------------------------------------------------------------------
    # 結果画面に表示します。
    #--------------------------------------------------------------------------
    @mstatus = res.mstatus
    if @mstatus == "success"
      # 成功の場合、カード選択画面に遷移
      @card_info_array = res.pay_now_id_response.account.card_info
      if @card_info_array.nil?
        @card_info_array = [Veritrans::Tercerog::Mdk::CardInfo.new]
      else
        @card_info_array << Veritrans::Tercerog::Mdk::CardInfo.new
      end

      @security_code_array = []

    else
      # それ以外の場合、決済結果画面に遷移
      @v_result_code = res.v_result_code
      @merr_msg = res.merr_msg

      if !res.pay_now_id_response.nil?
        @pay_now_id_status = res.pay_now_id_response.status
      end

      render :action => "execute"
      return
    end
  end

  #-------------------------------------------------------------------------
  # カード決済実行サンプル（本人認証あり）
  #-------------------------------------------------------------------------
  def execute
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # HTTP-Acceptの取得
    @http_accept = request.env["Accept"]
    # HTTP-USERAGENTの取得
    @http_user_agent = request.env["User-Agent"]

    # 会員ID
    @account_id = params[:account_id]
    # 取引ID
    @order_id = params[:order_id]
    # 金額
    @amount = params[:amount]
    # 決済種別
    @payment_mode = params[:payment_mode]
    # 与信方法
    @with_capture = params[:with_capture]
    # 支払方法
    @jpo1 = params[:jpo1]
    # 支払回数
    @jpo2 = params[:jpo2]
    # デバイスチャネル
    @device_channel = params[:device_channel]
    # カード保有者名
    @cardholder_name = params[:cardholder_name]

    # セッションに本人認証利用方式を格納
    session[SESSION_KEY_PAYMENT_MODE] = @payment_mode

    # 選択カードインデックス
    @select_card_index = params[:select_card_index]
    if @select_card_index.nil? || @select_card_index.empty?
      @select_card_index = -1
    else
      @select_card_index = @select_card_index.to_i
    end

    # カード情報件数
    card_info_count = params[:card_info_count]
    # カードID
    card_id = params[:card_id]
    # カード番号
    card_number = params[:card_number]
    # 有効期限
    card_expire = params[:card_expire]
    # セキュリティコード
    security_code = params[:security_code]

    # カード情報リスト
    @card_info_array = []
    @security_code_array = []
    for index in 0..(card_info_count.to_i - 1) do
      card_info = Veritrans::Tercerog::Mdk::CardInfo.new

      if !card_id.nil?
        card_info.card_id = card_id[index.to_s].to_s
      end

      if !card_number.nil?
        card_info.card_number = card_number[index.to_s].to_s
      end

      if !card_expire.nil?
        card_info.card_expire = card_expire[index.to_s].to_s
      end

      if !security_code.nil?
        @security_code_array << security_code[index.to_s].to_s
      else
        @security_code_array << ""
      end

      if index == @select_card_index
        # 選択された行
        if index == (card_info_count.to_i - 1)
          # 最終行の場合
          selected_card_id = ""
          selected_card_number = card_info.card_number
          selected_card_expire = card_info.card_expire
          selected_security_code = @security_code_array[index]
        else
          selected_card_id = card_info.card_id
          selected_card_number = ""
          selected_card_expire = ""
          selected_security_code = @security_code_array[index]
        end
      end

      @card_info_array << card_info
    end


    #-------------------------------------------------------------------------
    # 必須パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = nil
    if @order_id.nil? || @order_id.empty?
      # 取引ID
      @error_message = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>"

    elsif @amount.nil? || @amount.empty?
      # 金額
      @error_message = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>"
    end

    unless @error_message.nil?
      # エラーが存在する場合は入力画面に戻る。
      render :action => "select"
      return
    end

    # 本人認証利用方式を取得する。
    @mpi_payment_mode = get_mpi_payment_mode(@payment_mode)


    #-------------------------------------------------------------------------
    # 要求DTOを生成し、値を設定します。
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::MpiAuthorizeRequestDto.new
    req.service_option_type = @mpi_payment_mode.to_s
    req.account_id = @account_id.to_s
    req.order_id = @order_id.to_s
    req.amount = @amount.to_s
    req.card_id = selected_card_id
    req.card_number = selected_card_number
    req.card_expire = selected_card_expire
    req.security_code = selected_security_code
    req.http_accept = @http_accept.to_s
    req.http_user_agent = @http_user_agent.to_s

    if @jpo1 == "10" || @jpo1 == "80"
      req.jpo = @jpo1.to_s
    elsif @jpo1 == "61" && !@jpo2.empty?
      req.jpo = "#{@jpo1}C#{@jpo2}"
    end

    if @with_capture == "1"
      req.with_capture = "true"
    end

    req.device_channel = @device_channel.to_s
    req.cardholder_name = @cardholder_name.to_s

    #-------------------------------------------------------------------------
    # リダイレクト先URI（検証結果を返すURI）
    #-------------------------------------------------------------------------
    #yaml形式のconfig.ymlファイルを読み込む
    config = loadEnv4sample
    req.redirection_uri = config["PAYNOWID-MPI"]["redirection_url"].to_s

    ### 標準カードフラグを設定する場合に設定（未設定時は1が設定されたものと判断） ###
    #req.default_card = "1"


    #-------------------------------------------------------------------------
    # コマンドを実行し、応答DTOを取得します。
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)


    #--------------------------------------------------------------------------
    # 結果画面に表示します。
    #--------------------------------------------------------------------------
    # ログ
    puts "===== Debug Log ====="
    puts "PaymentMode[" + @mpi_payment_mode + "] : vResultCode=" + res.v_result_code

    if res.mstatus == "success"
      redirect_to res.auth_start_url
    end

    @order_id = res.order_id
    @mstatus = res.mstatus
    @v_result_code = res.v_result_code
    @merr_msg = res.merr_msg
    @redirect_html = ""

    if !res.pay_now_id_response.nil?
      @pay_now_id_status = res.pay_now_id_response.status
    end
  end

  #-------------------------------------------------------------------------
  # カード決済結果検索サンプル（本人認証あり）
  #-------------------------------------------------------------------------
  def search
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # リクエストID
    @request_id = params[:RequestId]
    # 決済種別
    @payment_mode = session[SESSION_KEY_PAYMENT_MODE]

    # 本人認証利用方式を取得する。
    @mpi_payment_mode = get_mpi_payment_mode(@payment_mode)


    #-------------------------------------------------------------------------
    # 要求DTOを生成し、値を設定します。
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::SearchRequestDto.new
    req.request_id = @request_id.to_s
    req.newer_flag = "false"


    #-------------------------------------------------------------------------
    # コマンドを実行し、応答DTOを取得します。
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)


    #--------------------------------------------------------------------------
    # 結果画面に表示します。
    #--------------------------------------------------------------------------
    @mstatus = res.mstatus
    @v_result_code = res.v_result_code
    @merr_msg = res.merr_msg

    if @mstatus != "success"
      # サーチ処理が失敗した場合
      @merr_msg = "サーチ処理が失敗しました。"
      return
    end

    # 本人認証結果とカード決済結果を取得
    unless res.order_infos.nil?
      # オーダー情報が存在する場合
      order_info_array = res.order_infos.order_info

      if !order_info_array.nil? && !order_info_array.empty?
        # リクエストID指定で検索したことから複数件存在しないことを前提に先頭の情報を取得
        order_info = order_info_array[0]
        @order_id = order_info.order_id
      end
    end

    # 本人認証～カード決済までが実行された場合、
    # このタイミングでリクエストIDによる検索を実行すると
    # txnKindが"mpi"と"card"のレコードがそれぞれ１件取得できる。
    unless order_info.nil?
      unless order_info.transaction_infos.nil?
        # トランザクション情報が存在する場合
        txn_info_array = order_info.transaction_infos.transaction_info

        # 最新の本人認証結果を取得
        mpi_txn_info = get_last_txn_info(txn_info_array, "mpi")
        # 最新のカード決済結果を取得
        card_txn_info = get_last_txn_info(txn_info_array, "card")
      end
    end

    # ログ
    puts "===== Debug Log ====="
    puts "PaymentMode=" + @mpi_payment_mode \
        + " : mStatusMPI=" + if mpi_txn_info.nil? then "" else mpi_txn_info.mstatus end \
        + ", vResultCodeMPI=" + if mpi_txn_info.nil? then "" else mpi_txn_info.v_result_code end \
        + ", vResultCodeCard=" + if card_txn_info.nil? then "" else card_txn_info.v_result_code end \

    # 完了画面に表示する結果コードは、基本的に本人認証の結果コードとなる。
    @mstatus = mpi_txn_info.mstatus unless mpi_txn_info.nil?
    @v_result_code = mpi_txn_info.v_result_code unless mpi_txn_info.nil?

    if @mstatus == "success"
      if @mpi_payment_mode != "1"
        # 本人認証成功で3D-Secure認証のみ(決済しない)以外の場合はカードの結果を表示
        @mstatus = card_txn_info.mstatus unless card_txn_info.nil?
        @v_result_code = card_txn_info.v_result_code unless card_txn_info.nil?
      end
    end
  end

  private

  #-------------------------------------------------------------------------
  # 指定した決済種別に対応する本人認証利用方式名を取得する。
  #-------------------------------------------------------------------------
  def get_mpi_payment_mode(payment_mode)

    #-------------------------------------------------------------------------
    # 本人認証利用方式
    #  1. 3D-Secure認証のみ（決済しない） : mpi-none
    #  2. 完全認証 : mpi-complete
    #  3. 通常認証（カード会社リスク負担） ： mpi-company
    #  4. 通常認証（カード会社、加盟店リスク負担）: mpi-merchant
    #-------------------------------------------------------------------------
    case payment_mode
      when "1"
        mpi_payment_mode = "mpi-none"
      when "2"
        mpi_payment_mode = "mpi-complete"
      when "3"
        mpi_payment_mode = "mpi-company"
      when "4"
        mpi_payment_mode = "mpi-merchant"
      else
        mpi_payment_mode = ""
    end
    return mpi_payment_mode
  end

  #-------------------------------------------------------------------------
  # 指定したトランザクション種別の中で最新のトランザクションを取得する。
  #-------------------------------------------------------------------------
  def get_last_txn_info(txn_info_array, txn_kind)

    if txn_info_array.nil? || txn_kind.nil?
      return nil
    end

    txn_id = -1
    result_txn_info = nil
    txn_info_array.each { |txn_info|

      proper_txn_info = txn_info.proper_transaction_info
      if !proper_txn_info.nil? && proper_txn_info.txn_kind == txn_kind
        # 指定したトランザクション種別と一致するトランザクションである場合

        if txn_id < txn_info.txn_id.to_i
          txn_id = txn_info.txn_id.to_i
          result_txn_info = txn_info
        end
      end
    }
    return result_txn_info
  end
end
