# -*- encoding: utf-8 -*-
class Web::Paynowid::Recurring::EntryController < ApplicationController

  SESSION_KEY_CARD_SELECT_ITEMS = "card_select_items".freeze

  #-------------------------------------------------------------------------
  # 入力フォーム初期表示
  #-------------------------------------------------------------------------
  def index
    @card_select_items = create_card_select_items(nil)
    session[SESSION_KEY_CARD_SELECT_ITEMS] = @card_select_items
    @card_select = ""
    load_token_api_info
  end

  #-------------------------------------------------------------------------
  # 継続課金管理(カード払い)要求サンプル
  #-------------------------------------------------------------------------
  def execute
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # 課金処理モード
    @charge_mode = params[:charge_mode]
    # 会員ID
    @account_id = params[:account_id]

    # 課金グループID
    @group_id = params[:group_id]
    # 課金開始日
    @start_date = params[:start_date]
    # 課金終了日
    @end_date = params[:end_date]
    # 都度／初回課金金額
    @one_time_amount = params[:one_time_amount]
    # 継続課金金額
    @recurring_amount = params[:recurring_amount]

    # カード選択
    @card_select = params[:card_select]
    # トークン
    @token = params[:token]


    # セッションからカード情報を取得
    @card_select_items = session[SESSION_KEY_CARD_SELECT_ITEMS]

    if !params[:get_card_info].blank?
      # カード情報取得処理の場合
      get_card_info

    else
      # 継続課金登録・更新処理の場合
      register
    end
  end

  private

  #-------------------------------------------------------------------------
  # カード情報取得サンプル
  #-------------------------------------------------------------------------
  def get_card_info


    #-------------------------------------------------------------------------
    # 必須パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = nil
    if @account_id.nil? || @account_id.empty?
      # 会員ID
      @error_message = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font><br/><br/>"
    end

    unless @error_message.nil?
      # エラーが存在する場合は入力画面に戻る。
      load_token_api_info
      render :action => "index"
      return
    end


    #-------------------------------------------------------------------------
    # 要求DTOを生成し、値を設定します。
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::CardInfoGetRequestDto.new
    req.account_id = @account_id.to_s


    #-------------------------------------------------------------------------
    # コマンドを実行し、応答DTOを取得します。
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)


    #--------------------------------------------------------------------------
    # 結果画面に表示します。
    #--------------------------------------------------------------------------
    @mstatus = res.mstatus
    if @mstatus == "success"
      # レスポンスからカード情報選択項目を生成
      @card_select_items = create_card_select_items(res.pay_now_id_response.account.card_info)
      session[SESSION_KEY_CARD_SELECT_ITEMS] = @card_select_items

      # 成功の場合は入力画面に遷移
      load_token_api_info
      render :action => "index"

    else
      # それ以外の場合は結果画面に遷移
      @v_result_code = res.v_result_code
      @merr_msg = res.merr_msg

      if !res.pay_now_id_response.nil?
        @pay_now_id_proc_id = res.pay_now_id_response.process_id
        @pay_now_id_status = res.pay_now_id_response.status
      end
    end
  end

  #-------------------------------------------------------------------------
  # 継続課金登録・更新サンプル
  #-------------------------------------------------------------------------
  def register
    #-------------------------------------------------------------------------
    # 必須パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = nil
    if @account_id.nil? || @account_id.empty?
      # 会員ID
      @error_message = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font><br/><br/>"

    elsif @group_id.nil? || @group_id.empty?
      # 課金グループID
      @error_message = "<font color='#ff0000'><b>必須項目：課金グループIDが指定されていません</b></font><br/><br/>"

    elsif @charge_mode == "2" && (!@start_date.nil? && !@start_date.empty?)
      # 課金開始日
      @error_message = "<font color='#ff0000'><b>課金開始日は指定できません</b></font><br/><br/>"

    end

    unless @error_message.nil?
      # エラーが存在する場合は入力画面に戻る。
      load_token_api_info
      render :action => "index"
      return
    end


    #-------------------------------------------------------------------------
    # 要求DTOを生成し、値を設定します。
    #-------------------------------------------------------------------------
    if @charge_mode == "1"
      #  新規課金開始
      req = Veritrans::Tercerog::Mdk::RecurringAddRequestDto.new

    elsif @charge_mode == "2"
      # 更新処理
      req = Veritrans::Tercerog::Mdk::RecurringUpdateRequestDto.new

    else
      # 未定義の項目
      @error_message = "<font color='#ff0000'><b>不正な処理です</b></font><br/><br/>"
      load_token_api_info
      render :action => "index"
      return
    end

    req.account_id = @account_id.to_s
    req.group_id = @group_id.to_s
    req.start_date = @start_date.to_s
    req.end_date = @end_date.to_s unless @end_date.nil?
    req.one_time_amount = @one_time_amount.to_s unless @one_time_amount.nil?
    req.amount = @recurring_amount.to_s unless @recurring_amount.nil?
    unless @card_select.nil? || @card_select.empty?
      req.card_id = @card_select.to_s
    else
      req.token = @token.to_s
    end


    #-------------------------------------------------------------------------
    # コマンドを実行し、応答DTOを取得します。
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)


    #--------------------------------------------------------------------------
    # 結果画面に表示します。
    #--------------------------------------------------------------------------
    @v_result_code = res.v_result_code
    @merr_msg = res.merr_msg

    if !res.pay_now_id_response.nil?
      @pay_now_id_proc_id = res.pay_now_id_response.process_id
      @pay_now_id_status = res.pay_now_id_response.status
    end
  end

  #-------------------------------------------------------------------------
  # カード情報選択項目を生成する。
  #-------------------------------------------------------------------------
  def create_card_select_items(card_info_array)

    items = [[:"新しいカードを登録する", ""]]
    unless card_info_array.nil?
      card_info_array.each do |info|
        items << [:"#{info.card_number} : #{info.card_expire}", info.card_id]
      end
    end
    return items
  end

  #-------------------------------------------------------------------------
  # MDKトークン設定情報を読み込む。
  #-------------------------------------------------------------------------
  def load_token_api_info
    config = loadEnv4sample
    @token_api_key = config["Token"]["token_api_key"].to_s
    @token_api_url = config["Token"]["token_api_url"].to_s
    if @token_api_url.blank?
      mdk_config = Veritrans::Tercerog::Mdk::MdkConfig.instance
      uri = URI.parse(mdk_config[:HOST_URL])
      @token_api_url = uri.to_s + "/4gtoken"
    end
  end

end
