# -*- encoding: utf-8 -*-
class Web::Push::PushReceiptController < ApplicationController

  # GWからの通知を受け取るため、Basic認証の設定を外します。
  skip_before_action :verify_authenticity_token

  #--------------------------------------------------------------
  # 初期処理
  #--------------------------------------------------------------
  def initialize
    # 結果通知の保存先
    @save_path = "#{rails_root}/tmp/push/"
  end

  #--------------------------------------------------------------
  # 結果通知受信 [銀行決済]
  #--------------------------------------------------------------
  def bank
    render :action => "index" unless performed?
    logger.info("銀行決済入金通知データ受取開始。")
    # リクエストヘッダを検証します。
    if check_message == false
      return
    end

    out_file_path = create_csv_file_path("bank")
    out = open(out_file_path, "w")
    logger.info("入金通知CSVファイル(" + out_file_path + ")へ書込開始。")

    tran_count = params[:numberOfNotify]
    for i in 0..tran_count.to_i - 1
      row = []

      # 取引ID
      row << get_push_param("orderId", i)
      # 収納機関コード
      row << get_push_param("kikanNo", i)
      # 収納企業コード
      row << get_push_param("kigyoNo", i)
      # 収納日時
      row << get_push_param("rcvDate", i)
      # お客様番号
      row << get_push_param("customerNo", i)
      # 確認番号
      row << get_push_param("confNo", i)
      # 入金金額
      row << get_push_param("rcvAmount", i)
      # ダミー決済フラグ
      row << get_push_param("dummy", i)

      out.write(row.join(',') + "\n")
    end
    out.close

    logger.info("入金通知CSVファイル(" + out_file_path + ")書込終了。")
    logger.info("入金通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答。")
  end

  #--------------------------------------------------------------
  # 結果通知受信 [コンビニ決済]
  #--------------------------------------------------------------
  def cvs
    render :action => "index" unless performed?
    logger.info("コンビニ決済入金通知データ受取開始。")
    # リクエストヘッダを検証します。
    if check_message == false
      return
    end

    out_file_path = create_csv_file_path("cvs")
    out = open(out_file_path, "w")
    logger.info("入金通知CSVファイル(" + out_file_path + ")へ書込開始。")

    tran_count = params[:numberOfNotify]
    for i in 0..tran_count.to_i - 1
      row = []

      # 取引ID
      row << get_push_param("orderId", i)
      # CVSタイプ
      row << get_push_param("cvsType", i)
      # 受付番号
      row << get_push_param("receiptNo", i)
      # 入金日時
      row << get_push_param("receiptDate", i)
      # 入金金額
      row << get_push_param("rcvAmount", i)
      # ダミー決済フラグ
      row << get_push_param("dummy", i)

      out.write(row.join(',') + "\n")
    end
    out.close

    logger.info("コンビニ入金通知CSVファイル(" + out_file_path + ")書込終了。")
    logger.info("コンビニ入金通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答。")
  end

  #--------------------------------------------------------------
  # 結果通知受信 [電子マネー決済]
  #--------------------------------------------------------------
  def em
    render :action => "index" unless performed?
    logger.info("電子マネー決済入金通知データ受取開始。")
    # リクエストヘッダを検証します。
    if check_message == false
      return
    end

    out_file_path = create_csv_file_path("em")
    out = open(out_file_path, "w")
    logger.info("入金通知CSVファイル(" + out_file_path + ")へ書込開始。")

    tran_count = params[:numberOfNotify]
    for i in 0..tran_count.to_i - 1
      row = []

      # 取引ID
      row << get_push_param("orderId", i)
      # 電子マネータイプ
      row << get_push_param("emType", i)
      # 完了日時
      row << get_push_param("receiptDate", i)
      # ダミー決済フラグ
      row << get_push_param("dummy", i)

      out.write(row.join(',') + "\n")
    end
    out.close

    logger.info("電子マネー入金通知CSVファイル(" + out_file_path + ")書込終了。")
    logger.info("電子マネー入金通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答。")
  end

  #--------------------------------------------------------------
  # 結果通知受信 [カード決済(3D認証付き)]
  #--------------------------------------------------------------
  def mpi
    render :action => "index" unless performed?
    logger.info("カード決済(3D認証付き)結果通知データ受取開始。")
    # リクエストヘッダを検証します。
    if check_message == false
      return
    end

    out_file_path = create_csv_file_path("mpi")
    out = open(out_file_path, "w")
    logger.info("入金通知CSVファイル(" + out_file_path + ")へ書込開始。")

    tran_count = params[:numberOfNotify]
    for i in 0..tran_count.to_i - 1
      row = []

      # 取引ID
      row << get_push_param("orderId", i)
      # 結果コード
      row << get_push_param("vResultCode", i)
      # トランザクションタイプ
      row << get_push_param("txnType", i)
      # MPI結果ステータス
      row << get_push_param("mpiMstatus", i)
      # カード結果ステータス
      row << get_push_param("cardMstatus", i)
      # ダミーフラグ
      row << get_push_param("dummy", i)

      out.write(row.join(',') + "\n")
    end
    out.close

    logger.info("カード決済(3D認証付き)結果通知CSVファイル(" + out_file_path + ")書込終了。")
    logger.info("カード決済(3D認証付き)結果通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答。")
  end

  #--------------------------------------------------------------
  # 結果通知受信 [Paypal決済]
  #--------------------------------------------------------------
  def paypal
    render :action => "index" unless performed?
    logger.info("Paypal決済入金通知データ受取開始。")
    # リクエストヘッダを検証します。
    if check_message == false
      return
    end

    @fixed = params[:fixed]
    logger.info("速報/確報フラグ：" + @fixed)

    out_file_path = create_csv_file_path("paypal")
    out = open(out_file_path, "w")
    logger.info("入金通知CSVファイル(" + out_file_path + ")へ書込開始。")

    tran_count = params[:numberOfNotify]
    for i in 0..tran_count.to_i - 1
      row = []

      # 取引ID
      row << get_push_param("orderId", i)
      # 結果ステータス
      row << get_push_param("mstatus", i)
      # トランザクションタイプ
      row << get_push_param("txnType", i)
      # 受付日時
      row << get_push_param("receivedDatetime", i)
      # 金額
      row << get_push_param("amount", i)
      # お客様番号
      row << get_push_param("payerId", i)
      # 取引識別子
      row << get_push_param("centerTxnId", i)
      # ダミー決済フラグ
      row << get_push_param("dummy", i)

      out.write(row.join(',') + "\n")
    end
    out.close

    logger.info("Paypal入金通知CSVファイル(" + out_file_path + ")書込終了。")
    logger.info("Paypal入金通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答。")
  end

  #--------------------------------------------------------------
  # 結果通知受信 [UPOP決済]
  #--------------------------------------------------------------
  def upop
    render :action => "index" unless performed?
    logger.info("UPOP決済結果通知データ受取開始。")
    # リクエストヘッダを検証します。
    if check_message == false
      return
    end

    out_file_path = create_csv_file_path("upop")
    out = open(out_file_path, "w")
    logger.info("入金通知CSVファイル(" + out_file_path + ")へ書込開始。")

    tran_count = params[:numberOfNotify]
    for i in 0..tran_count.to_i - 1
      row = []

      # 取引ID
      row << get_push_param("orderId", i)
      # サービスコマンド
      row << get_push_param("txnType", i)
      # 結果ステータス
      row << get_push_param("mstatus", i)
      # システム追跡番号
      row << get_push_param("traceNumber", i)
      # 認証サービス日時
      row << get_push_param("traceTime", i)
      # 清算金額
      row << get_push_param("settleAmount", i)
      # 清算日付
      row << get_push_param("settleDate", i)
      # 清算レート
      row << get_push_param("settleRate", i)
      # ダミー決済フラグ
      row << get_push_param("dummy", i)
      # 詳細結果コード
      row << get_push_param("vResultCode", i)
      # 決済センターとの取引ID
      row << get_push_param("upopOrderId", i)

      out.write(row.join(',') + "\n")
    end
    out.close

    logger.info("UPOP結果通知CSVファイル(" + out_file_path + ")書込終了。")
    logger.info("UPOP結果通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答。")
  end

  #--------------------------------------------------------------
  # 結果通知受信 [Alipay決済]
  #--------------------------------------------------------------
  def alipay
    render :action => "index" unless performed?
    logger.info("Alipay決済結果通知データ受取開始。")
    # リクエストヘッダを検証します。
    if check_message == false
      return
    end

    out_file_path = create_csv_file_path("alipay")
    out = open(out_file_path, "w")
    logger.info("入金通知CSVファイル(" + out_file_path + ")へ書込開始。")

    tran_count = params[:numberOfNotify]
    for i in 0..tran_count.to_i - 1
      row = []

      # 取引ID
      row << get_push_param("orderId", i)
      # サービスコマンド
      row << get_push_param("txnType", i)
      # 結果ステータス
      row << get_push_param("mstatus", i)
      # 結果コード
      row << get_push_param("vResultCode", i)
      # 決済センター取引ID
      row << get_push_param("centerTradeId", i)
      # 決済センター取引ID
      row << get_push_param("centerTradeId", i)
      # ダミー決済フラグ
      row << get_push_param("dummy", i)

      out.write(row.join(',') + "\n")
    end
    out.close

    logger.info("Alipay結果通知CSVファイル(" + out_file_path + ")書込終了。")
    logger.info("Alipay結果通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答。")
  end

  #--------------------------------------------------------------
  # 結果通知受信 [キャリア決済]
  #--------------------------------------------------------------
  def carrier
    render :action => "index" unless performed?
    logger.info("キャリア決済入金通知データ受取開始。")
    # リクエストヘッダを検証します。
    if check_message == false
      return
    end

    out_file_path = create_csv_file_path("carrier")
    out = open(out_file_path, "w")
    logger.info("入金通知CSVファイル(" + out_file_path + ")へ書込開始。")

    tran_count = params[:numberOfNotify]
    for i in 0..tran_count.to_i - 1
      row = []

      # 取引ID
      row << get_push_param("orderId", i)
      # 通知種類
      row << get_push_param("txnType", i)
      # 発生時刻
      row << get_push_param("txnTime", i)
      # 結果コード
      row << get_push_param("vResultCode", i)
      # ステータス
      row << get_push_param("mstatus", i)
      # キャリアオーダーID
      row << get_push_param("crOrderId", i)
      # OpenId
      row << get_push_param("openId", i)
      # 対象年月
      row << get_push_param("month", i)
      # ダミー決済フラグ
      row << get_push_param("dummy", i)

      out.write(row.join(',') + "\n")
    end
    out.close

    logger.info("キャリア入金通知CSVファイル(" + out_file_path + ")書込終了。")
    logger.info("キャリア入金通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答。")
  end

  #--------------------------------------------------------------
  # 結果通知受信 [ショッピングクレジット決済]
  #--------------------------------------------------------------
  def oricosc
    render :action => "index" unless performed?
    logger.info("審査結果通知データ受取開始。")
    # リクエストヘッダを検証します。
    if check_message == false
      return
    end

    out_file_path = create_csv_file_path("oricosc")
    out = open(out_file_path, "w")
    logger.info("入金通知CSVファイル(" + out_file_path + ")へ書込開始。")

    tran_count = params[:numberOfNotify]
    for i in 0..tran_count.to_i - 1
      row = []

      # 取引ID
      row << get_push_param("orderId", i)
      # 注文番号
      row << get_push_param("oricoOrderNo", i)
      # 審査結果
      row << get_push_param("orderStateCode", i)
      # 受付番号
      row << get_push_param("receiptNo", i)
      # 承認番号
      row << get_push_param("approvalNo", i)
      # 申込日
      row << get_push_param("requestDate", i)
      # ローン元金
      row << get_push_param("loanPrincipal", i)
      # 支払回数
      row << get_push_param("paymentCount", i)
      #ダミー決済フラグ
      row << get_push_param("dummy", i)

      out.write(row.join(',') + "\n")
    end
    out.close

    logger.info("審査結果通知CSVファイル(" + out_file_path + ")書込終了。")
    logger.info("審査結果通知通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答。")
  end

  #--------------------------------------------------------------
  # 結果通知受信 [楽天ID決済]
  #--------------------------------------------------------------
  def rakuten
    render :action => "index" unless performed?
    logger.info("審査結果通知データ受取開始。")
    # リクエストヘッダを検証します。
    if check_message == false
      return
    end

    out_file_path = create_csv_file_path("rakuten")
    out = open(out_file_path, "w")
    logger.info("入金通知CSVファイル(" + out_file_path + ")へ書込開始。")

    tran_count = params[:numberOfNotify]
    for i in 0..tran_count.to_i - 1
      row = []

      # 取引ID
      row << get_push_param("orderId", i)
      # 楽天注文番号
      row << get_push_param("rakutenOrderId", i)
      # 通知種類
      row << get_push_param("txnType", i)
      # 発生時刻
      row << get_push_param("txnTime", i)
      # 結果コード
      row << get_push_param("vResultCode", i)
      # ステータス
      row << get_push_param("mstatus", i)
      # 残高
      row << get_push_param("balance", i)
      # 利用ポイント
      row << get_push_param("usedPoint", i)
      # 楽天APIエラーコード
      row << get_push_param("rakutenApiErrorCode", i)
      # 楽天取引エラーコード
      row << get_push_param("rakutenOrderErrorCode", i)
      # ダミーフラグ
      row << get_push_param("dummy", i)
      # 楽天APIエラータイプ
      row << get_push_param("rakutenApiErrorType", i)
      # 決済取引ID
      row << get_push_param("gatewayOrderId", i)
      # クレジットカードのブランド
      row << get_push_param("cardBrand", i)
      # クレジットカード番号の下4桁
      row << get_push_param("cardLast4", i)
      # 分割払いの回数
      row << get_push_param("cardInstallments", i)
      # セキュリティコード認証利用有無
      row << get_push_param("cardCvc", i)
      # 3D セキュア認証利用有無
      row << get_push_param("card3ds", i)
      # 取消受付期限
      row << get_push_param("cancelExpirationTime", i)
      # 売上受付期限
      row << get_push_param("captureExpirationTime", i)
      # 金額変更受付期限
      row << get_push_param("updateExpirationTime", i)
      # 与信延長受付期限
      row << get_push_param("extendAuthExpirationTime", i)
      # 顧客ID
      row << get_push_param("customerId", i)
      # 楽天承諾時取引ID
      row << get_push_param("rakutenConsentOrderId", i)

      out.write(row.join(',') + "\n")
    end
    out.close

    logger.info("楽天ID決済結果通知CSVファイル(" + out_file_path + ")書込終了。")
    logger.info("楽天ID決済結果通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答。")
  end

  #--------------------------------------------------------------
  # 結果通知受信 [リクルートかんたん支払い]
  #--------------------------------------------------------------
  def recruit
    render :action => "index" unless performed?
    logger.info("審査結果通知データ受取開始。")
    # リクエストヘッダを検証します。
    if check_message == false
      return
    end

    out_file_path = create_csv_file_path("recruit")
    out = open(out_file_path, "w")
    logger.info("入金通知CSVファイル(" + out_file_path + ")へ書込開始。")

    tran_count = params[:numberOfNotify]
    for i in 0..tran_count.to_i - 1
      row = []

      # 取引ID
      row << get_push_param("orderId", i)
      # リクルート注文番号
      row << get_push_param("recruitOrderId", i)
      # 通知種類
      row << get_push_param("txnType", i)
      # 発生時刻
      row << get_push_param("txnTime", i)
      # 結果コード
      row << get_push_param("vResultCode", i)
      # ステータス
      row << get_push_param("mstatus", i)
      # 利用ポイント
      row << get_push_param("usePoint", i)
      # 付与ポイント
      row << get_push_param("givePoint", i)
      # ダミーフラグ
      row << get_push_param("dummy", i)

      out.write(row.join(',') + "\n")
    end
    out.close

    logger.info("リクルートかんたん支払い結果通知CSVファイル(" + out_file_path + ")書込終了。")
    logger.info("リクルートかんたん支払い結果通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答。")
  end

  #--------------------------------------------------------------
  # 結果通知受信 [LINE Pay]
  #--------------------------------------------------------------
  def linepay
    render :action => "index" unless performed?
    logger.info("審査結果通知データ受取開始。")
    # リクエストヘッダを検証します。
    if check_message == false
      return
    end

    out_file_path = create_csv_file_path("linepay")
    out = open(out_file_path, "w")
    logger.info("入金通知CSVファイル(" + out_file_path + ")へ書込開始。")

    tran_count = params[:numberOfNotify]
    for i in 0..tran_count.to_i - 1
      row = []

      # 取引ID
      row << get_push_param("orderId", i)
      # LINE Pay注文番号
      row << get_push_param("linepayOrderId", i)
      # 通知種類
      row << get_push_param("txnType", i)
      # 発生時刻
      row << get_push_param("txnTime", i)
      # 結果コード
      row << get_push_param("vResultCode", i)
      # ステータス
      row << get_push_param("mstatus", i)
      # ダミーフラグ
      row << get_push_param("dummy", i)

      out.write(row.join(',') + "\n")
    end
    out.close

    logger.info("LINE Pay結果通知CSVファイル(" + out_file_path + ")書込終了。")
    logger.info("LINE Pay結果通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答。")
  end

  #--------------------------------------------------------------
  # 結果通知受信 [PayPay]
  #--------------------------------------------------------------
  def paypay
    render :action => "index" unless performed?
    logger.info("PayPay決済申込結果データ受取開始。")
    # リクエストヘッダを検証します。
    if check_message == false
      return
    end

    out_file_path = create_csv_file_path("paypay")
    out = open(out_file_path, "w")
    logger.info("PayPay決済申込結果通知CSVファイル(" + out_file_path + ")へ書込開始。")

    tran_count = params[:numberOfNotify]
    for i in 0..tran_count.to_i - 1
      row = []

      # 取引ID
      row << get_push_param("orderId", i)
      # PayPay取引ID
      row << get_push_param("paypayOrderId", i)
      # トランザクションタイプ
      row << get_push_param("txnType", i)
      # 発生時刻
      row << get_push_param("txnTime", i)
      # 詳細結果コード
      row << get_push_param("vResultCode", i)
      # 処理ステータス
      row << get_push_param("mstatus", i)
      # 残高
      row << get_push_param("balance", i)
      # ダミーフラグ
      row << get_push_param("dummy", i)

      out.write(row.join(',') + "\n")
    end
    out.close

    logger.info("PayPay決済申込結果通知CSVファイル(" + out_file_path + ")書込終了。")
    logger.info("PayPay決済申込結果通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答。")
  end

  #--------------------------------------------------------------
  # 結果通知受信 [Amazon Pay]
  #--------------------------------------------------------------
  def amazonpay
    render :action => "index" unless performed?
    logger.info("審査結果通知データ受取開始。")
    # リクエストヘッダを検証します。
    if check_message == false
      return
    end

    out_file_path = create_csv_file_path("amazonpay")
    out = open(out_file_path, "w")
    logger.info("入金通知CSVファイル(" + out_file_path + ")へ書込開始。")

    tran_count = params[:numberOfNotify]
    for i in 0..tran_count.to_i - 1
      row = []

      # 取引ID
      row << get_push_param("orderId", i)
      # 通知種類
      row << get_push_param("txnType", i)
      # 発生時刻
      row << get_push_param("txnTime", i)
      # 結果コード
      row << get_push_param("vResultCode", i)
      # ステータス
      row << get_push_param("mstatus", i)
      # 決済センターの管理ID
      row << get_push_param("centerOrderId", i)
      # 決済センターのトランザクション管理ID
      row << get_push_param("centerTransactionId", i)
      # 返金可能金額
      row << get_push_param("refundableAmount", i)
      # 残高
      row << get_push_param("balance", i)
      # ダミーフラグ
      row << get_push_param("dummy", i)

      out.write(row.join(',') + "\n")
    end
    out.close

    logger.info("Amazon Pay結果通知CSVファイル(" + out_file_path + ")書込終了。")
    logger.info("Amazon Pay結果通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答。")
  end

  private

  #--------------------------------------------------------------
  # 改ざんチェック用のHMACをリクエストヘッダより取得しメッセージを検証します。
  # 検証に失敗した場合は、500 Internal Server Error を発生させます。
  #--------------------------------------------------------------
  def check_message

    @content_hmac = request.headers['content-hmac']

    # content-hmacがリクエストヘッダに存在しない場合はエラーとします。
    if @content_hmac.blank?
      logger.error("入金通知データの受信に失敗しました。")
      render(:file => "#{rails_root}/public/500.html", :status => "500 ERROR")
      return false
    end
    # マーチャントユーティリティを利用してメッセージの改ざんをチェックします。
    #if Veritrans::Tercerog::Mdk::MdkMerchantUtility::check_message_by_secret_key?(merchant_secret_key, request.body.read, @content_hmac)
    if Veritrans::Tercerog::Mdk::MdkMerchantUtility::check_message?(request.body.read, @content_hmac)
      logger.info("入金通知データの検証に成功しました。")
      return true
    else
      logger.error("入金通知データの検証に失敗しました。")
      render(:file => "#{rails_root}/public/500.html", :status => "500 ERROR")
      return false
    end
  end

  #--------------------------------------------------------------
  # 指定した名称に紐付く通知パラメータを取得する。
  #--------------------------------------------------------------
  def get_push_param(name, index)

    pos = index.to_s.rjust(4, '0')
    value = params["#{name}#{pos}"]

    value = "" if value.nil?
    return value
  end

  #--------------------------------------------------------------
  # 通知内容の出力先となるファイルパスを生成する。
  #--------------------------------------------------------------
  def create_csv_file_path(service)

    push_time = params[:pushTime]
    push_id = params[:pushId]
    service_name = service.capitalize
    return "#{@save_path}#{service_name}-#{push_time}-#{push_id}.csv"
  end
end
