# -*- encoding: utf-8 -*-
class Web::Recruit::AuthorizeController < ApplicationController

  # set_dummy_request を実行する
  # after_action では render の後に実行されるため
  before_action :set_dummy_request

  #-------------------------------------------------------------------------
  # 入力フォーム初期表示
  #-------------------------------------------------------------------------
  def index
    @order_id  = "dummy" + Time.now.to_i.to_s
    @amount    = params[:price].to_s
    @item_name = params[:item_name].to_s

    #yaml形式のconfig.ymlファイルを読み込む
    config = loadEnv4sample

    #各種URLを取得
    @success_url = config["Recruit"]["success_url"]
    @error_url   = config["Recruit"]["error_url"]
    @push_url    = config["Recruit"]["push_url"]
  end

  #-------------------------------------------------------------------------
  # before_action で実行されるメソッド
  def set_dummy_request
    # ダミーモード判定
    mdk_config = Veritrans::Tercerog::Mdk::MdkConfig.instance
    @dummy_request = mdk_config[:DUMMY_REQUEST]
  end

  #-------------------------------------------------------------------------
  # リクルートかんたん支払い 与信要求サンプル
  #-------------------------------------------------------------------------
  def execute
    #-------------------------------------------------------------------------
    # パラメータを取得します。
    #-------------------------------------------------------------------------
    # 取引ID
    @order_id = params[:order_id]
    # 支払金額
    @amount = params[:amount]
    # 与信方法
    @with_capture = params[:with_capture]
    #商品番号
    @item_id = params[:item_id]
    #商品名
    @item_name = params[:item_name]
    #決済完了時URL
    @success_url = params[:success_url]
    #決済エラー時URL
    @error_url = params[:error_url]
    #プッシュURL
    @push_url = params[:push_url]

    #-------------------------------------------------------------------------
    # 取引ID更新の場合の処理
    #-------------------------------------------------------------------------
    unless params[:update_id].blank?
      @order_id = "dummy" + Time.now.to_i.to_s
      render :action => "index"
      return
    end

    #-------------------------------------------------------------------------
    #  入力パラメータ値チェック
    #-------------------------------------------------------------------------
    @error_message = ""
    if @order_id.nil? || @order_id.empty?
      @error_message = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font><br/><br/>"
      @order_id = "dummy" + Time.now.to_i.to_s
      render :action => "index"
      return
    end
    if @amount.nil? || @amount.empty?
      @error_message = "<font color='#ff0000'><b>必須項目：決済金額が指定されていません</b></font><br/><br/>"
      render :action => "index"
      return
    end
    if @item_name.nil? || @item_name.empty?
      @error_message = "<font color='#ff0000'><b>必須項目：商品名が指定されていません</b></font><br/><br/>"
      render :action => "index"
      return
    end
    # ダミーモード判定
    unless @push_url.nil? || @push_url.empty?
      mdk_config = Veritrans::Tercerog::Mdk::MdkConfig.instance
      unless mdk_config[:DUMMY_REQUEST] == Veritrans::Tercerog::Mdk::MdkConst::DUMMY_MODE_TRUE
          @error_message = "<font color='#ff0000'><b>プッシュURLはダミーモードのときにのみ指定可能です</b></font><br/><br/>"
          render :action => "index"
          return
      end
    end

    #-------------------------------------------------------------------------
    # 要求電文パラメータ値の指定
    #-------------------------------------------------------------------------
    req = Veritrans::Tercerog::Mdk::RecruitAuthorizeRequestDto.new
    req.order_id = @order_id.to_s
    req.amount = @amount.to_s
    req.with_capture = @with_capture.to_s

    req.item_id = @item_id.to_s
    req.item_name = @item_name.to_s
    req.success_url = @success_url.to_s
    req.error_url = @error_url.to_s
    req.push_url = @push_url.to_s unless @push_url.nil?

    #-------------------------------------------------------------------------
    #  実施
    #-------------------------------------------------------------------------
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    res = tran.execute(req)
    @response_data = res
    @request_data = req

    #--------------------------------------------------------------------------
    #レスポンスの取得
    #--------------------------------------------------------------------------

    # ログ
    puts "===== Debug Log ====="
    puts "vResultCode=" + @response_data.v_result_code

    @no_header_footer = "false"
    if @response_data.mstatus.to_s == Veritrans::Tercerog::Mdk::MdkConst::SUCCESS
      if !res.redirect_url.nil?
        redirect_to res.redirect_url, :status => 302
      end
    end

    @v_result_code = res.v_result_code
    @result_order_id = res.order_id
    @use_point = params[:use_point]
    @give_point = params[:give_point]
    @mstatus = res.mstatus
    @merr_msg = res.merr_msg
  end

end
