# -*- encoding: utf-8 -*-
class Web::Search::SearchController < ApplicationController
  #-------------------------------------------------------------------------
  # 検索サンプル
  #-------------------------------------------------------------------------
  def execute

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # パラメータを取得します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 共通項目
    requestId = params[:requestId].to_s             # リクエストID
    serviceTypeCd = params[:serviceTypeCd]          # 決済サービスタイプ
    orderId = params[:orderId].to_s                 # 取引ID
    command = params[:command]                      # コマンド
    mstatus = params[:mstatus]                      # ステータスコード
    orderStatus = params[:orderStatus]              # オーダー決済状態
    txnDatatimeFrom = params[:txnDatatimeFrom].to_s # 取引日時 From
    txnDatatimeTo = params[:txnDatatimeTo].to_s     # 取引日時 To
    amountFrom = params[:amountFrom].to_s           # 金額 From
    amountTo = params[:amountTo].to_s               # 金額 To
    is_newer_flg = params[:newerFlag]               # 最新トランザクションフラグ
    is_newer_flg = "false" if is_newer_flg.nil?     # nil(未チェック)は "false"

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 画面パラメータから新しいパラメータの型を生成します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 取引日時の範囲指定パラメータを生成します。
    txnDatatimeRange = Veritrans::Tercerog::Mdk::SearchRange.new
    txnDatatimeRange.from = txnDatatimeFrom
    txnDatatimeRange.to = txnDatatimeTo
    # 金額の範囲指定パラメータを生成します。
    amountRange = Veritrans::Tercerog::Mdk::SearchRange.new
    amountRange.from = amountFrom
    amountRange.to = amountTo


    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 要求DTOを生成し、値を設定します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # Commonパラメータクラスへのセット
    common_param = Veritrans::Tercerog::Mdk::CommonSearchParameter.new
    common_param.order_id = orderId
    if command != nil
      common_param.command = command
    end
    if mstatus != nil
      common_param.mstatus = mstatus
    end
    if orderStatus != nil
      common_param.order_status = orderStatus
    end
    common_param.txn_datetime = txnDatatimeRange
    common_param.amount = amountRange

    # Searchパラメータクラスへのセット
    search_param = Veritrans::Tercerog::Mdk::SearchParameters.new
    search_param.common = common_param

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # サービス固有項目のパラメータを設定します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # ========================================
    # クレジットカード
    # ========================================
    if check_service(serviceTypeCd, "card")
      # サービス固有項目の画面パラメータを取得
      card_dddTransactionId = params[:card_dddTransactionId] # 3d-xid

      # 設定
      card_param = Veritrans::Tercerog::Mdk::CardSearchParameter.new
      card_param.ddd_transaction_id = card_dddTransactionId

      # 検索パラメータに設定
      search_param.card = card_param
    end
    # ========================================
    # クレジットカード（本人認証）
    # ========================================
    if check_service(serviceTypeCd, "mpi")
      # サービス固有項目の画面パラメータを取得
      mpi_detailOrderType = params[:mpi_detailOrderType]                  # 詳細取引決済状態
      mpi_res3dTransactionId = params[:mpi_res3dTransactionId]            # 応答3DトランザクションID
      mpi_res3dTransactionStatus = params[:mpi_res3dTransactionStatus]    # 応答3Dトランザクションステータス
      mpi_res3dEci = params[:mpi_res3dEci]                                # 応答3D ECI
      mpi_deviceChannel = params[:mpi_deviceChannel]                      # デバイスチャネル
      mpi_accountType = params[:mpi_accountType]                          # アカウントタイプ

      # 設定
      mpi_param = Veritrans::Tercerog::Mdk::MpiSearchParameter.new
      mpi_param.detail_order_type= mpi_detailOrderType
      mpi_param.res3d_transaction_id = mpi_res3dTransactionId
      mpi_param.res3d_transaction_status = mpi_res3dTransactionStatus
      mpi_param.res3d_eci = mpi_res3dEci
      mpi_param.device_channel = mpi_deviceChannel
      mpi_param.account_type = mpi_accountType

      # 検索パラメータに設定
      search_param.mpi = mpi_param
    end
    # ========================================
    # 電子マネー
    # ========================================
    if check_service(serviceTypeCd, "em")
      # サービス固有項目の画面パラメータを取得
      em_emType = params[:em_emType] # 電子マネー種別
      em_emType = Array.new if em_emType.nil?
      em_settlementLimitFrom = params[:em_settlementLimitFrom]   # 支払/受取期限 From
      em_settlementLimitTo = params[:em_settlementLimitTo]       # 支払/受取期限 To
      em_completeDatetimeFrom = params[:em_completeDatetimeFrom] # 支払完了日時 From
      em_completeDatetimeTo = params[:em_completeDatetimeTo]     # 支払完了日時 To
      em_receiptNo = params[:em_receiptNo]                       # 受付番号

      # 支払/受取期限の範囲指定パラメータを生成
      em_settlementLimitRange = Veritrans::Tercerog::Mdk::SearchRange.new
      em_settlementLimitRange.from = em_settlementLimitFrom
      em_settlementLimitRange.to = em_settlementLimitTo
      # 支払完了日時の範囲指定パラメータを生成
      em_completeDatetimeRange = Veritrans::Tercerog::Mdk::SearchRange.new
      em_completeDatetimeRange.from = em_completeDatetimeFrom
      em_completeDatetimeRange.to = em_completeDatetimeTo

      # 設定
      em_param = Veritrans::Tercerog::Mdk::EmSearchParameter.new
      em_param.em_type = em_emType
      em_param.settlement_limit = em_settlementLimitRange
      em_param.complete_datetime = em_completeDatetimeRange
      em_param.receipt_no = em_receiptNo unless em_receiptNo.nil?

      # 検索パラメータに設定
      search_param.em = em_param
    end
    # ========================================
    # コンビニ
    # ========================================
    if check_service(serviceTypeCd, "cvs")
      # サービス固有項目の画面パラメータを取得
      cvs_cvsType = params[:cvs_cvsType]                                   # コンビニタイプ
      cvs_cvsType = Array.new if cvs_cvsType.nil?
      cvs_payLimitFrom = params[:cvs_payLimitFrom]                         # 支払期限 From
      cvs_payLimitTo = params[:cvs_payLimitTo]                             # 支払期限 To
      cvs_payLimitDatetimeFrom = params[:cvs_payLimitDatetimeFrom]         # 支払期限日時 From
      cvs_payLimitDatetimeTo = params[:cvs_payLimitDatetimeTo]             # 支払期限日時 To
      cvs_paidDatetimeFrom = params[:cvs_paidDatetimeFrom]                 # 入金受付日 From
      cvs_paidDatetimeTo = params[:cvs_paidDatetimeTo]                     # 入金受付日 To
      # 支払期限の範囲指定パラメータを生成
      cvs_payLimitRange = Veritrans::Tercerog::Mdk::SearchRange.new
      cvs_payLimitRange.from = cvs_payLimitFrom
      cvs_payLimitRange.to = cvs_payLimitTo
      # 支払期限日時の範囲指定パラメータを生成
      cvs_payLimitDatetimeRange = Veritrans::Tercerog::Mdk::SearchRange.new
      cvs_payLimitDatetimeRange.from = cvs_payLimitDatetimeFrom
      cvs_payLimitDatetimeRange.to = cvs_payLimitDatetimeTo
      # 入金受付日の範囲指定パラメータを生成
      cvs_paidDatetimeRange = Veritrans::Tercerog::Mdk::SearchRange.new
      cvs_paidDatetimeRange.from = cvs_paidDatetimeFrom
      cvs_paidDatetimeRange.to = cvs_paidDatetimeTo

      # 設定
      cvs_param = Veritrans::Tercerog::Mdk::CvsSearchParameter.new
      cvs_param.cvs_type = cvs_cvsType
      cvs_param.pay_limit = cvs_payLimitRange
      cvs_param.pay_limit_datetime = cvs_payLimitDatetimeRange
      cvs_param.paid_datetime = cvs_paidDatetimeRange

      # 検索パラメータに設定
      search_param.cvs = cvs_param
    end
    # ========================================
    # 銀行
    # ========================================
    if check_service(serviceTypeCd, "bank")
      # サービス固有項目の画面パラメータを取得
      bank_payLimitFrom = params[:bank_payLimitFrom]                 # 支払期限 From
      bank_payLimitTo = params[:bank_payLimitTo]                     # 支払期限 To
      bank_receivedDatetimeFrom = params[:bank_receivedDatetimeFrom] # 収納日時 From
      bank_receivedDatetimeTo = params[:bank_receivedDatetimeTo]     # 収納日時 To
      bank_shunoKikanNo = params[:bank_shunoKikanNo]                 # 収納機関番号
      bank_shunoKigyoNo = params[:bank_shunoKigyoNo]                 # 収納企業コード
      bank_customerNo = params[:bank_customerNo]                     # お客様番号
      bank_confirmNo = params[:bank_confirmNo]                       # 確認番号

      # 支払期限の範囲指定パラメータを生成
      bank_payLimitRange = Veritrans::Tercerog::Mdk::SearchRange.new
      bank_payLimitRange.from = bank_payLimitFrom
      bank_payLimitRange.to = bank_payLimitTo
      # 収納日時の範囲指定パラメータを生成
      bank_receivedDatetimeRange = Veritrans::Tercerog::Mdk::SearchRange.new
      bank_receivedDatetimeRange.from = bank_receivedDatetimeFrom
      bank_receivedDatetimeRange.to = bank_receivedDatetimeTo

      # 設定
      bank_param = Veritrans::Tercerog::Mdk::BankSearchParameter.new
      bank_param.pay_limit = bank_payLimitRange
      bank_param.received_datetime = bank_receivedDatetimeRange
      bank_param.shuno_kikan_no = bank_shunoKikanNo unless bank_shunoKikanNo.nil?
      bank_param.shuno_kigyo_no = bank_shunoKigyoNo unless bank_shunoKigyoNo.nil?
      bank_param.customer_no = bank_customerNo unless bank_customerNo.nil?
      bank_param.confirm_no = bank_confirmNo unless bank_confirmNo.nil?

      # 検索パラメータに設定
      search_param.bank = bank_param
    end
    # ========================================
    # PayPal
    # ========================================
    if check_service(serviceTypeCd, "paypal")
      # サービス固有項目の画面パラメータを取得
      paypal_paymentDatetimeFrom = params[:paypal_paymentDatetimeFrom] # 支払日時 From
      paypal_paymentDatetimeTo = params[:paypal_paymentDatetimeTo]     # 支払日時 To
      paypal_invoiceId = params[:paypal_invoiceId]                     # 請求番号
      paypal_payerId = params[:paypal_payerId]                         # 顧客番号

      # 支払日時の範囲指定パラメータを生成
      paypal_paymentDatetimeRange = Veritrans::Tercerog::Mdk::SearchRange.new
      paypal_paymentDatetimeRange.from = paypal_paymentDatetimeFrom
      paypal_paymentDatetimeRange.to = paypal_paymentDatetimeTo

      # 設定
      paypal_param = Veritrans::Tercerog::Mdk::PaypalSearchParameter.new
      paypal_param.payment_datetime = paypal_paymentDatetimeRange
      paypal_param.invoice_id = paypal_invoiceId
      paypal_param.payer_id = paypal_payerId

      # 検索パラメータに設定
      search_param.paypal = paypal_param
    end

    # ========================================
    # Saison
    # ========================================
    if check_service(serviceTypeCd, "saison")
      # サービス固有項目の画面パラメータを取得
      saison_totalAmountFrom = params[:saison_totalAmountFrom]   # 合計決済金額 From
      saison_totalAmountTo = params[:saison_totalAmountTo]       # 合計決済金額 To
      saison_walletAmountFrom = params[:saison_walletAmountFrom] # ウォレット決済金額 From
      saison_walletAmountTo = params[:saison_walletAmountTo]     # ウォレット決済金額 To
      saison_cardAmountFrom = params[:saison_cardAmountFrom]     # カード決済金額 From
      saison_cardAmountTo = params[:saison_cardAmountTo]         # カード決済金額 To

      # 合計決済金額の範囲指定パラメータを生成
      saison_totalAmountRange = Veritrans::Tercerog::Mdk::SearchRange.new
      saison_totalAmountRange.from = saison_totalAmountFrom
      saison_totalAmountRange.to = saison_totalAmountTo

      # ウォレット決済金額の範囲指定パラメータを生成
      saison_walletAmountRange = Veritrans::Tercerog::Mdk::SearchRange.new
      saison_walletAmountRange.from = saison_walletAmountFrom
      saison_walletAmountRange.to = saison_walletAmountTo

      # カード決済金額の範囲指定パラメータを生成
      saison_cardAmountRange = Veritrans::Tercerog::Mdk::SearchRange.new
      saison_cardAmountRange.from = saison_cardAmountFrom
      saison_cardAmountRange.to = saison_cardAmountTo

      # 設定
      saison_param = Veritrans::Tercerog::Mdk::SaisonSearchParameter.new
      saison_param.total_amount = saison_totalAmountRange
      saison_param.wallet_amount = saison_walletAmountRange
      saison_param.card_amount = saison_cardAmountRange

      # 検索パラメータに設定
      search_param.saison = saison_param
    end

    # ========================================
    # 銀聯ネット決済(UPOP)
    # ========================================
    if check_service(serviceTypeCd, "upop")

      # サービス固有項目の画面パラメータを取得
      upop_settle_datetime_jp_from = params[:upop_settleDatetimeJpFrom]
      upop_settle_datetime_jp_to = params[:upop_settleDatetimeJpTo]
      upop_settle_datetime_cn_from = params[:upop_settleDatetimeCnFrom]
      upop_settle_datetime_cn_to = params[:upop_settleDatetimeCnTo]
      upop_detail_order_type = params[:upopDetailOrderType]

      upop_payment_datetime_range_jp = Veritrans::Tercerog::Mdk::SearchRange.new
      upop_payment_datetime_range_jp.from = upop_settle_datetime_jp_from
      upop_payment_datetime_range_jp.to =   upop_settle_datetime_jp_to

      upop_payment_datetime_range_cn = Veritrans::Tercerog::Mdk::SearchRange.new
      upop_payment_datetime_range_cn.from = upop_settle_datetime_cn_from
      upop_payment_datetime_range_cn.to =  upop_settle_datetime_cn_to

      upop_param = Veritrans::Tercerog::Mdk::UpopSearchParameter.new
      upop_param.settle_datetime_jp = upop_payment_datetime_range_jp
      upop_param.settle_datetime_cn = upop_payment_datetime_range_cn
      unless upop_detail_order_type.nil?
        upop_param.detail_order_type = upop_detail_order_type
      end

      # 検索パラメータに設定
      search_param.upop =  upop_param
    end

    # ========================================
    # Alipay
    # ========================================
    if check_service(serviceTypeCd, "alipay")
      # サービス固有項目の画面パラメータを取得
      alipay_detail_order_type = params[:alipayDetailOrderType]
      alipay_center_trade_id = params[:alipay_centerTradeId]
      alipay_payment_time_from = params[:alipay_paymentTimeFrom]
      alipay_payment_time_to = params[:alipay_paymentTimeTo]
      alipay_settlement_time_from = params[:alipay_settlementTimeFrom]
      alipay_settlement_time_to = params[:alipay_settlementTimeTo]
      alipay_pay_type = params[:alipay_payType]

      alipay_payment_time_range = Veritrans::Tercerog::Mdk::SearchRange.new
      alipay_payment_time_range.from = alipay_payment_time_from
      alipay_payment_time_range.to = alipay_payment_time_to

      alipay_settlement_time_range = Veritrans::Tercerog::Mdk::SearchRange.new
      alipay_settlement_time_range.from = alipay_settlement_time_from
      alipay_settlement_time_range.to = alipay_settlement_time_to

      alipay_param = Veritrans::Tercerog::Mdk::AlipaySearchParameter.new
      unless alipay_detail_order_type.blank?
        alipay_param.detail_order_type = alipay_detail_order_type
      end
      alipay_param.center_trade_id = alipay_center_trade_id
      alipay_param.payment_time =  alipay_payment_time_range
      alipay_param.settlement_time =  alipay_settlement_time_range
      unless alipay_pay_type.blank?
        alipay_param.pay_type = alipay_pay_type
      end

      # 検索パラメータに設定
      search_param.alipay =  alipay_param
    end

    # ========================================
    # キャリア
    # ========================================
    if check_service(serviceTypeCd, "carrier")
      carrier_detail_order_type   = params[:carrier_detail_order_type]   # 詳細取引決済状態
      carrier_detail_order_type   = Array.new if carrier_detail_order_type.nil?
      carrier_cr_service_type     = params[:carrier_cr_service_type]     # キャリア種別
      carrier_cr_service_type     = Array.new if carrier_cr_service_type.nil?
      carrier_item_type           = params[:carrier_item_type]           # 商品タイプ（デジコン等）
      carrier_item_type           = Array.new if carrier_item_type.nil?
      carrier_mp_status           = params[:carrier_mp_status]           # 継続状態
      carrier_mp_status           = Array.new if carrier_mp_status.nil?
      carrier_terminal_kind       = params[:carrier_terminal_kind]       # 端末種別
      carrier_terminal_kind       = Array.new if carrier_terminal_kind.nil?
      carrier_detail_command_type = params[:carrier_detail_command_type] # 詳細コマンドタイプ
      carrier_detail_command_type = Array.new if carrier_detail_command_type.nil?
      # 配列ではない項目
      carrier_accounting_type     = params[:carrier_accounting_type]     # 都度or継続
      carrier_mp_first_date = params[:carrier_mp_first_date]             # 初回課金年月日
      carrier_mp_day = params[:carrier_mp_day]                           # 継続課金日
      carrier_item_id = params[:carrier_item_id]                         # 商品番号

      # 設定
      carrier_param = Veritrans::Tercerog::Mdk::CarrierSearchParameter.new
      carrier_param.detail_order_type   = carrier_detail_order_type
      carrier_param.cr_service_type     = carrier_cr_service_type
      carrier_param.accounting_type     = carrier_accounting_type unless carrier_accounting_type.nil?
      carrier_param.item_type           = carrier_item_type
      carrier_param.mp_status           = carrier_mp_status
      carrier_param.terminal_kind       = carrier_terminal_kind
      carrier_param.detail_command_type = carrier_detail_command_type
      carrier_param.mp_first_date       = carrier_mp_first_date unless carrier_mp_first_date.nil?
      carrier_param.mp_day              = carrier_mp_day unless carrier_mp_day.nil?
      carrier_param.item_id             = carrier_item_id unless carrier_item_id.nil?

      # 検索パラメータに設定
      search_param.carrier = carrier_param
    end

    # ========================================
    # ショッピングクレジット
    # ========================================
    if check_service(serviceTypeCd, "oricosc")
      # サービス固有項目の画面パラメータを取得
      oricosc_orico_order_no = params[:oricosc_orico_order_no]                 # 注文番号
      oricosc_amount_from = params[:oricosc_amount_from]                       # 支払合計金額From
      oricosc_amount_to = params[:oricosc_amount_to]                           # 支払合計金額To
      oricosc_total_item_amount_from = params[:oricosc_total_item_amount_from] # 商品価格合計(税込)From
      oricosc_total_item_amount_to = params[:oricosc_total_item_amount_to]     # 商品価格合計(税込)To

      # 支払金額合計の範囲指定パラメータを生成
      oricosc_amount_range = Veritrans::Tercerog::Mdk::SearchRange.new
      oricosc_amount_range.from = oricosc_amount_from
      oricosc_amount_range.to = oricosc_amount_to

      # 商品価格合計(税込)の範囲指定パラメータを生成
      oricosc_total_item_amount_range = Veritrans::Tercerog::Mdk::SearchRange.new
      oricosc_total_item_amount_range.from = oricosc_total_item_amount_from
      oricosc_total_item_amount_range.to = oricosc_total_item_amount_to

      # 設定
      oricosc_param = Veritrans::Tercerog::Mdk::OricoscSearchParameter.new
      oricosc_param.orico_order_no = oricosc_orico_order_no
      oricosc_param.amount = oricosc_amount_range
      oricosc_param.total_item_amount = oricosc_total_item_amount_range

      # 検索パラメータに設定
      search_param.oricosc = oricosc_param
    end

    # ========================================
    # 楽天
    # ========================================
    if check_service(serviceTypeCd, "rakuten")
      # サービス固有項目の画面パラメータを取得
      rakuten_detail_order_type   = params[:rakuten_detail_order_type]            # 詳細取引決済状態
      rakuten_detail_command_type = params[:rakuten_detail_command_type]          # 詳細コマンドタイプ
      rakuten_item_id             = params[:rakuten_item_id]                      # 商品番号
      rakuten_pay_type            = params[:rakuten_pay_type]                     # 決済種別
      rakuten_accounting_type     = params[:rakuten_accounting_type]              # 課金種別
      rakuten_consent_status      = params[:rakuten_consent_status]               # 承諾状態
      rakuten_original_order_id   = params[:rakuten_original_order_id]            # 元取引ID
      rakuten_detail_order_type   = Array.new if rakuten_detail_order_type.nil?
      rakuten_detail_command_type = Array.new if rakuten_detail_command_type.nil?
      rakuten_pay_type            = Array.new if rakuten_pay_type.nil?
      rakuten_consent_status      = Array.new if rakuten_consent_status.nil?

      # 設定
      rakuten_param = Veritrans::Tercerog::Mdk::RakutenSearchParameter.new
      rakuten_param.detail_order_type   = rakuten_detail_order_type
      rakuten_param.detail_command_type = rakuten_detail_command_type
      rakuten_param.item_id             = rakuten_item_id unless rakuten_item_id.nil?
      rakuten_param.pay_type            = rakuten_pay_type
      rakuten_param.accounting_type           = rakuten_accounting_type unless rakuten_accounting_type.nil?
      rakuten_param.consent_status            = rakuten_consent_status
      rakuten_param.original_order_id         = rakuten_original_order_id unless rakuten_original_order_id.nil?

      # 検索パラメータに設定
      search_param.rakuten = rakuten_param
    end

    # ========================================
    # リクルート
    # ========================================
    if check_service(serviceTypeCd, "recruit")
      # サービス固有項目の画面パラメータを取得
      recruit_detail_order_type   = params[:recruit_detail_order_type]   # 詳細取引決済状態
      recruit_detail_order_type   = Array.new if recruit_detail_order_type.nil?
      recruit_detail_command_type = params[:recruit_detail_command_type] # 詳細コマンドタイプ
      recruit_detail_command_type = Array.new if recruit_detail_command_type.nil?
      recruit_item_id = params[:recruit_item_id]                         # 商品番号

      # 設定
      recruit_param = Veritrans::Tercerog::Mdk::RecruitSearchParameter.new
      recruit_param.detail_order_type   = recruit_detail_order_type
      recruit_param.detail_command_type = recruit_detail_command_type
      recruit_param.item_id             = recruit_item_id unless recruit_item_id.nil?

      # 検索パラメータに設定
      search_param.recruit = recruit_param
    end

    # ========================================
    # LINE Pay
    # ========================================
    if check_service(serviceTypeCd, "linepay")
      # サービス固有項目の画面パラメータを取得
      linepay_detail_order_type   = params[:linepay_detail_order_type]   # 詳細取引決済状態
      linepay_detail_order_type   = Array.new if linepay_detail_order_type.nil?
      linepay_detail_command_type = params[:linepay_detail_command_type] # 詳細コマンドタイプ
      linepay_detail_command_type = Array.new if linepay_detail_command_type.nil?
      linepay_item_id = params[:linepay_item_id]                         # 商品番号

      # 設定
      linepay_param = Veritrans::Tercerog::Mdk::LinepaySearchParameter.new
      linepay_param.detail_order_type   = linepay_detail_order_type
      linepay_param.detail_command_type = linepay_detail_command_type
      linepay_param.item_id             = linepay_item_id unless linepay_item_id.nil?

      # 検索パラメータに設定
      search_param.linepay = linepay_param
    end

    # ========================================
    # MasterPass
    # ========================================
    if check_service(serviceTypeCd, "masterpass")
      # サービス固有項目の画面パラメータを取得
      masterpass_detail_order_type   = params[:masterpass_detail_order_type]   # 詳細取引決済状態
      masterpass_detail_order_type   = Array.new if masterpass_detail_order_type.nil?
      masterpass_detail_command_type = params[:masterpass_detail_command_type] # 詳細コマンドタイプ
      masterpass_detail_command_type = Array.new if masterpass_detail_command_type.nil?
      masterpass_item_id = params[:masterpass_item_id]                         # 商品番号
      masterpass_acquirer_code = params[:masterpass_acquirer_code]             # 仕向け先コード

      # 設定
      masterpass_param = Veritrans::Tercerog::Mdk::MasterpassSearchParameter.new
      masterpass_param.detail_order_type   = masterpass_detail_order_type
      masterpass_param.detail_command_type = masterpass_detail_command_type
      masterpass_param.item_id             = masterpass_item_id unless masterpass_item_id.nil?
      masterpass_param.acquirer_code       = masterpass_acquirer_code unless masterpass_acquirer_code.nil?

      # 検索パラメータに設定
      search_param.masterpass = masterpass_param
    end

    # ========================================
    # 銀行振込
    # ========================================
    if check_service(serviceTypeCd, "virtualacc")
      # サービス固有項目の画面パラメータを取得
      virtualacc_detail_order_type   = params[:virtualacc_detail_order_type]       # 詳細取引決済状態
      virtualacc_detail_order_type   = Array.new if virtualacc_detail_order_type.nil?
      virtualacc_detail_command_type = params[:virtualacc_detail_command_type]     # 詳細コマンドタイプ
      virtualacc_detail_command_type = Array.new if virtualacc_detail_command_type.nil?
      virtualacc_entry_transfer_name = params[:virtualacc_entry_transfer_name]     # 登録時振込人名
      virtualacc_entry_transfer_number = params[:virtualacc_entry_transfer_number] # 登録時振込番号
      virtualacc_account_number = params[:virtualacc_account_number]               # 口座番号

      # 設定
      virtualacc_param = Veritrans::Tercerog::Mdk::VirtualaccSearchParameter.new
      virtualacc_param.detail_order_type   = virtualacc_detail_order_type
      virtualacc_param.detail_command_type = virtualacc_detail_command_type
      virtualacc_param.entry_transfer_name = virtualacc_entry_transfer_name
      virtualacc_param.entry_transfer_number = virtualacc_entry_transfer_number
      virtualacc_param.account_number = virtualacc_account_number

      # 検索パラメータに設定
      search_param.virtualacc = virtualacc_param
    end

    # ========================================
    # PayPay
    # ========================================
    if check_service(serviceTypeCd, "paypay")
      # サービス固有項目の画面パラメータを取得
      paypay_detail_order_type   = params[:paypay_detail_order_type]   # 詳細取引決済状態
      paypay_detail_order_type   = Array.new if paypay_detail_order_type.nil?
      paypay_detail_command_type = params[:paypay_detail_command_type] # 詳細コマンドタイプ
      paypay_detail_command_type = Array.new if paypay_detail_command_type.nil?
      paypay_service_type        = params[:paypay_service_type]        # PayPayサービスタイプ
      paypay_service_type        = Array.new if paypay_service_type.nil?

      # 設定
      paypay_param = Veritrans::Tercerog::Mdk::PaypaySearchParameter.new
      paypay_param.detail_order_type   = paypay_detail_order_type
      paypay_param.detail_command_type = paypay_detail_command_type
      paypay_param.paypay_service_type = paypay_service_type unless paypay_service_type.nil?

      # 検索パラメータに設定
      search_param.paypay = paypay_param
    end

    # ========================================
    # Amazon Pay
    # ========================================
    if check_service(serviceTypeCd, "amazonpay")
      # サービス固有項目の画面パラメータを取得
      amazonpay_detail_order_type     = params[:amazonpay_detail_order_type]           # 詳細取引決済状態
      amazonpay_detail_command_type   = params[:amazonpay_detail_command_type]         # 詳細コマンドタイプ
      amazonpay_center_order_id       = params[:amazonpay_center_order_id]             # 決済センターの管理ID
      amazonpay_center_transaction_id = params[:amazonpay_center_transaction_id]       # 決済センターのトランザクション管理ID
      amazonpay_pay_confirm_screen_type = params[:amazonpay_pay_confirm_screen_type]   # 決済確認画面種別
      amazonpay_detail_order_type     = Array.new if amazonpay_detail_order_type.nil?
      amazonpay_detail_command_type   = Array.new if amazonpay_detail_command_type.nil?
      amazonpay_center_order_id       = Array.new if amazonpay_center_order_id.nil?
      amazonpay_center_transaction_id = Array.new if amazonpay_center_transaction_id.nil?

      # 設定
      amazonpay_param = Veritrans::Tercerog::Mdk::AmazonpaySearchParameter.new
      amazonpay_param.detail_order_type     = amazonpay_detail_order_type
      amazonpay_param.detail_command_type   = amazonpay_detail_command_type
      amazonpay_param.center_order_id       = amazonpay_center_order_id
      amazonpay_param.center_transaction_id = amazonpay_center_transaction_id
      amazonpay_param.pay_confirm_screen_type = amazonpay_pay_confirm_screen_type unless amazonpay_original_order_id.nil?

      # 検索パラメータに設定
      search_param.amazonpay = amazonpay_param
    end

    # 検索DTOへパラメータクラスをセット
    request_data = Veritrans::Tercerog::Mdk::SearchRequestDto.new
    request_data.request_id = requestId            # リクエストID
    request_data.newer_flag = is_newer_flg         # 商品に紐付く最後の取引のみ対象にするかを示す
    request_data.contain_dummy_flag = "1"          # 検索対象にダミー決済のレコードを含めるかを示す
    if serviceTypeCd != nil
      request_data.service_type_cd = serviceTypeCd # 検索対象のサービスタイプを示す
    end
    request_data.search_parameters = search_param  # 各機能の固有条件

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # コマンドを実行し、応答DTOを取得します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    response_data = tran.execute(request_data)


    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 結果画面に表示します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 処理結果メッセージを設定（View機能へ引き渡す）
    warning = response_data.merr_msg
    if warning != nil && 0 < warning.size
        @error_message = "<font color='#ff0000' size='2'><b>" + warning + "</b></font><br/><br/>"
    end

    # 配列データを設定（View機能へ引き渡す）
    order_infos = response_data.order_infos
    unless order_infos.nil?
        @order_info = order_infos.order_info
    end
  end

  # サービスタイプコードのチェックを行う。
  def check_service(target, key)
    if target.nil?
      result = false
    else
      result = target.include?(key)
    end
  end


  # キャリアの詳細検索結果画面
  def detail_carrier
    order_id = params[:order_id]
    if order_id.nil? || order_id.empty?
        @error_message = "<font color='#ff0000' size='2'><b>取引IDが取得できませんでした</b></font><br/><br/>"
    end

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 要求DTOを生成し、値を設定します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # Commonパラメータクラスへのセット
    common_param = Veritrans::Tercerog::Mdk::CommonSearchParameter.new
    common_param.order_id = order_id

    # Searchパラメータクラスへのセット
    search_param = Veritrans::Tercerog::Mdk::SearchParameters.new
    search_param.common = common_param

    # 設定
    carrier_param = Veritrans::Tercerog::Mdk::CarrierSearchParameter.new
    carrier_param.cr_service_type     = Array.new
    carrier_param.item_type           = Array.new
    carrier_param.mp_status           = Array.new
    carrier_param.terminal_kind       = Array.new
    carrier_param.detail_command_type = Array.new

    # 検索パラメータに設定
    search_param.carrier = carrier_param

    # 検索DTOへパラメータクラスをセット
    request_data = Veritrans::Tercerog::Mdk::SearchRequestDto.new
    request_data.service_type_cd = Array.new(["carrier"]) # キャリアのみ指定
    request_data.contain_dummy_flag = "1"                 # 検索対象にダミー決済のレコードを含めるかを示す
    request_data.search_parameters = search_param         # 各機能の固有条件

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # コマンドを実行し、応答DTOを取得します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    response_data = tran.execute(request_data)

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 結果画面に表示します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 処理結果メッセージを設定（View機能へ引き渡す）
    warning = response_data.merr_msg
    if !warning.nil? && !warning.empty?
        @error_message = "<font color='#ff0000' size='2'><b>" + warning + "</b></font><br/><br/>"
    end

    # 配列データを設定（View機能へ引き渡す）
    order_infos = response_data.order_infos
    if !order_infos.nil?
        @order_info = order_infos.order_info
    end
  end

  # 楽天の詳細検索結果画面
  def detail_rakuten
    order_id = params[:order_id]
    if order_id.nil? || order_id.empty?
        @error_message = "<font color='#ff0000' size='2'><b>取引IDが取得できませんでした</b></font><br/><br/>"
    end

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 要求DTOを生成し、値を設定します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # Commonパラメータクラスへのセット
    common_param = Veritrans::Tercerog::Mdk::CommonSearchParameter.new
    common_param.order_id = order_id

    # Searchパラメータクラスへのセット
    search_param = Veritrans::Tercerog::Mdk::SearchParameters.new
    search_param.common = common_param

    # 設定
    rakuten_param = Veritrans::Tercerog::Mdk::RakutenSearchParameter.new
    rakuten_param.detail_command_type = Array.new

    # 検索パラメータに設定
    search_param.rakuten = rakuten_param

    # 検索DTOへパラメータクラスをセット
    request_data = Veritrans::Tercerog::Mdk::SearchRequestDto.new
    request_data.service_type_cd    = Array.new(["rakuten"]) # 楽天のみ指定
    request_data.contain_dummy_flag = "1"                    # 検索対象にダミー決済のレコードを含めるかを示す
    request_data.search_parameters  = search_param           # 各機能の固有条件

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # コマンドを実行し、応答DTOを取得します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    response_data = tran.execute(request_data)

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 結果画面に表示します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 処理結果メッセージを設定（View機能へ引き渡す）
    warning = response_data.merr_msg
    if !warning.nil? && !warning.empty?
        @error_message = "<font color='#ff0000' size='2'><b>" + warning + "</b></font><br/><br/>"
    end

    # 配列データを設定（View機能へ引き渡す）
    order_infos = response_data.order_infos
    if !order_infos.nil?
        @order_info = order_infos.order_info
    end
  end

  # リクルートの詳細検索結果画面
  def detail_recruit
    order_id = params[:order_id]
    if order_id.nil? || order_id.empty?
        @error_message = "<font color='#ff0000' size='2'><b>取引IDが取得できませんでした</b></font><br/><br/>"
    end

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 要求DTOを生成し、値を設定します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # Commonパラメータクラスへのセット
    common_param = Veritrans::Tercerog::Mdk::CommonSearchParameter.new
    common_param.order_id = order_id

    # Searchパラメータクラスへのセット
    search_param = Veritrans::Tercerog::Mdk::SearchParameters.new
    search_param.common = common_param

    # 設定
    recruit_param = Veritrans::Tercerog::Mdk::RecruitSearchParameter.new
    recruit_param.detail_command_type = Array.new

    # 検索パラメータに設定
    search_param.recruit = recruit_param

    # 検索DTOへパラメータクラスをセット
    request_data = Veritrans::Tercerog::Mdk::SearchRequestDto.new
    request_data.service_type_cd = Array.new(["recruit"]) # リクルートのみ指定
    request_data.contain_dummy_flag = "1"                 # 検索対象にダミー決済のレコードを含めるかを示す
    request_data.search_parameters = search_param         # 各機能の固有条件

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # コマンドを実行し、応答DTOを取得します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    response_data = tran.execute(request_data)

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 結果画面に表示します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 処理結果メッセージを設定（View機能へ引き渡す）
    warning = response_data.merr_msg
    if !warning.nil? && !warning.empty?
        @error_message = "<font color='#ff0000' size='2'><b>" + warning + "</b></font><br/><br/>"
    end

    # 配列データを設定（View機能へ引き渡す）
    order_infos = response_data.order_infos
    if !order_infos.nil?
        @order_info = order_infos.order_info
    end
  end

  # LINE Payの詳細検索結果画面
  def detail_linepay
    order_id = params[:order_id]
    if order_id.nil? || order_id.empty?
        @error_message = "<font color='#ff0000' size='2'><b>取引IDが取得できませんでした</b></font><br/><br/>"
    end

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 要求DTOを生成し、値を設定します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # Commonパラメータクラスへのセット
    common_param = Veritrans::Tercerog::Mdk::CommonSearchParameter.new
    common_param.order_id = order_id

    # Searchパラメータクラスへのセット
    search_param = Veritrans::Tercerog::Mdk::SearchParameters.new
    search_param.common = common_param

    # 設定
    linepay_param = Veritrans::Tercerog::Mdk::LinepaySearchParameter.new
    linepay_param.detail_command_type = Array.new

    # 検索パラメータに設定
    search_param.linepay = linepay_param

    # 検索DTOへパラメータクラスをセット
    request_data = Veritrans::Tercerog::Mdk::SearchRequestDto.new
    request_data.service_type_cd = Array.new(["linepay"]) # LINE Payのみ指定
    request_data.contain_dummy_flag = "1"                 # 検索対象にダミー決済のレコードを含めるかを示す
    request_data.search_parameters = search_param         # 各機能の固有条件

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # コマンドを実行し、応答DTOを取得します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    response_data = tran.execute(request_data)

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 結果画面に表示します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 処理結果メッセージを設定（View機能へ引き渡す）
    warning = response_data.merr_msg
    if !warning.nil? && !warning.empty?
        @error_message = "<font color='#ff0000' size='2'><b>" + warning + "</b></font><br/><br/>"
    end

    # 配列データを設定（View機能へ引き渡す）
    order_infos = response_data.order_infos
    if !order_infos.nil?
        @order_info = order_infos.order_info
    end
  end

  # MasterPassの詳細検索結果画面
  def detail_masterpass
    order_id = params[:order_id]
    if order_id.nil? || order_id.empty?
        @error_message = "<font color='#ff0000' size='2'><b>取引IDが取得できませんでした</b></font><br/><br/>"
    end

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 要求DTOを生成し、値を設定します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # Commonパラメータクラスへのセット
    common_param = Veritrans::Tercerog::Mdk::CommonSearchParameter.new
    common_param.order_id = order_id

    # Searchパラメータクラスへのセット
    search_param = Veritrans::Tercerog::Mdk::SearchParameters.new
    search_param.common = common_param

    # 設定
    masterpass_param = Veritrans::Tercerog::Mdk::MasterpassSearchParameter.new
    masterpass_param.detail_command_type = Array.new

    # 検索パラメータに設定
    search_param.masterpass = masterpass_param

    # 検索DTOへパラメータクラスをセット
    request_data = Veritrans::Tercerog::Mdk::SearchRequestDto.new
    request_data.service_type_cd = Array.new(["masterpass"]) # MasterPassのみ指定
    request_data.contain_dummy_flag = "1"                    # 検索対象にダミー決済のレコードを含めるかを示す
    request_data.search_parameters = search_param            # 各機能の固有条件

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # コマンドを実行し、応答DTOを取得します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    response_data = tran.execute(request_data)

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 結果画面に表示します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 処理結果メッセージを設定（View機能へ引き渡す）
    warning = response_data.merr_msg
    if !warning.nil? && !warning.empty?
        @error_message = "<font color='#ff0000' size='2'><b>" + warning + "</b></font><br/><br/>"
    end

    # 配列データを設定（View機能へ引き渡す）
    order_infos = response_data.order_infos
    if !order_infos.nil?
        @order_info = order_infos.order_info
    end
  end

  # 銀行振込の詳細検索結果画面
  def detail_virtualacc
    order_id = params[:order_id]
    if order_id.nil? || order_id.empty?
        @error_message = "<font color='#ff0000' size='2'><b>取引IDが取得できませんでした</b></font><br/><br/>"
    end

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 要求DTOを生成し、値を設定します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # Commonパラメータクラスへのセット
    common_param = Veritrans::Tercerog::Mdk::CommonSearchParameter.new
    common_param.order_id = order_id

    # Searchパラメータクラスへのセット
    search_param = Veritrans::Tercerog::Mdk::SearchParameters.new
    search_param.common = common_param

    # 設定
    virtualacc_param = Veritrans::Tercerog::Mdk::VirtualaccSearchParameter.new
    virtualacc_param.detail_command_type = Array.new

    # 検索パラメータに設定
    search_param.virtualacc = virtualacc_param

    # 検索DTOへパラメータクラスをセット
    request_data = Veritrans::Tercerog::Mdk::SearchRequestDto.new
    request_data.service_type_cd = Array.new(["virtualacc"]) # 銀行振込のみ指定
    request_data.contain_dummy_flag = "1"                    # 検索対象にダミー決済のレコードを含めるかを示す
    request_data.search_parameters = search_param            # 各機能の固有条件

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # コマンドを実行し、応答DTOを取得します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    response_data = tran.execute(request_data)

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 結果画面に表示します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 処理結果メッセージを設定（View機能へ引き渡す）
    warning = response_data.merr_msg
    if !warning.nil? && !warning.empty?
        @error_message = "<font color='#ff0000' size='2'><b>" + warning + "</b></font><br/><br/>"
    end

    # 配列データを設定（View機能へ引き渡す）
    order_infos = response_data.order_infos
    if !order_infos.nil?
        @order_info = order_infos.order_info
    end
  end

  # Alipayの詳細検索結果画面
  def detail_alipay
    order_id = params[:order_id]
    if order_id.nil? || order_id.empty?
        @error_message = "<font color='#ff0000' size='2'><b>取引IDが取得できませんでした</b></font><br/><br/>"
    end

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 要求DTOを生成し、値を設定します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # Commonパラメータクラスへのセット
    common_param = Veritrans::Tercerog::Mdk::CommonSearchParameter.new
    common_param.order_id = order_id

    # Searchパラメータクラスへのセット
    search_param = Veritrans::Tercerog::Mdk::SearchParameters.new
    search_param.common = common_param

    # 設定
    alipay_param = Veritrans::Tercerog::Mdk::AlipaySearchParameter.new
    alipay_param.detail_order_type = Array.new

    # 検索パラメータに設定
    search_param.alipay = alipay_param

    # 検索DTOへパラメータクラスをセット
    request_data = Veritrans::Tercerog::Mdk::SearchRequestDto.new
    request_data.service_type_cd = Array.new(["alipay"]) # Alipayのみ指定
    request_data.contain_dummy_flag = "1"                # 検索対象にダミー決済のレコードを含めるかを示す
    request_data.search_parameters = search_param        # 各機能の固有条件

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # コマンドを実行し、応答DTOを取得します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    response_data = tran.execute(request_data)

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 結果画面に表示します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 処理結果メッセージを設定（View機能へ引き渡す）
    warning = response_data.merr_msg
    if !warning.nil? && !warning.empty?
        @error_message = "<font color='#ff0000' size='2'><b>" + warning + "</b></font><br/><br/>"
    end

    # 配列データを設定（View機能へ引き渡す）
    order_infos = response_data.order_infos
    if !order_infos.nil?
        @order_info = order_infos.order_info
    end
  end

  # UPOPの詳細検索結果画面
  def detail_upop
    order_id = params[:order_id]
    if order_id.nil? || order_id.empty?
        @error_message = "<font color='#ff0000' size='2'><b>取引IDが取得できませんでした</b></font><br/><br/>"
    end

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 要求DTOを生成し、値を設定します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # Commonパラメータクラスへのセット
    common_param = Veritrans::Tercerog::Mdk::CommonSearchParameter.new
    common_param.order_id = order_id

    # Searchパラメータクラスへのセット
    search_param = Veritrans::Tercerog::Mdk::SearchParameters.new
    search_param.common = common_param

    # 設定
    upop_param = Veritrans::Tercerog::Mdk::UpopSearchParameter.new
    upop_param.detail_order_type = Array.new

    # 検索パラメータに設定
    search_param.upop = upop_param

    # 検索DTOへパラメータクラスをセット
    request_data = Veritrans::Tercerog::Mdk::SearchRequestDto.new
    request_data.service_type_cd = Array.new(["upop"]) # UPOPのみ指定
    request_data.contain_dummy_flag = "1"              # 検索対象にダミー決済のレコードを含めるかを示す
    request_data.search_parameters = search_param      # 各機能の固有条件

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # コマンドを実行し、応答DTOを取得します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    response_data = tran.execute(request_data)

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 結果画面に表示します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 処理結果メッセージを設定（View機能へ引き渡す）
    warning = response_data.merr_msg
    if !warning.nil? && !warning.empty?
        @error_message = "<font color='#ff0000' size='2'><b>" + warning + "</b></font><br/><br/>"
    end

    # 配列データを設定（View機能へ引き渡す）
    order_infos = response_data.order_infos
    if !order_infos.nil?
        @order_info = order_infos.order_info
    end
  end

  # PayPayの詳細検索結果画面
  def detail_paypay
    order_id = params[:order_id]
    if order_id.nil? || order_id.empty?
        @error_message = "<font color='#ff0000' size='2'><b>取引IDが取得できませんでした</b></font><br/><br/>"
    end

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 要求DTOを生成し、値を設定します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # Commonパラメータクラスへのセット
    common_param = Veritrans::Tercerog::Mdk::CommonSearchParameter.new
    common_param.order_id = order_id

    # Searchパラメータクラスへのセット
    search_param = Veritrans::Tercerog::Mdk::SearchParameters.new
    search_param.common = common_param

    # 設定
    paypay_param = Veritrans::Tercerog::Mdk::PaypaySearchParameter.new
    paypay_param.detail_command_type = Array.new

    # 検索パラメータに設定
    search_param.paypay = paypay_param

    # 検索DTOへパラメータクラスをセット
    request_data = Veritrans::Tercerog::Mdk::SearchRequestDto.new
    request_data.service_type_cd = Array.new(["paypay"])  # PayPayのみ指定
    request_data.contain_dummy_flag = "1"                 # 検索対象にダミー決済のレコードを含めるかを示す
    request_data.search_parameters = search_param         # 各機能の固有条件

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # コマンドを実行し、応答DTOを取得します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    response_data = tran.execute(request_data)

    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 結果画面に表示します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 処理結果メッセージを設定（View機能へ引き渡す）
    warning = response_data.merr_msg
    if !warning.nil? && !warning.empty?
        @error_message = "<font color='#ff0000' size='2'><b>" + warning + "</b></font><br/><br/>"
    end

    # 配列データを設定（View機能へ引き渡す）
    order_infos = response_data.order_infos
    if !order_infos.nil?
        @order_info = order_infos.order_info
    end
  end

  # Amazon Payの詳細検索結果画面
  def detail_amazonpay
    order_id = params[:order_id]
    if order_id.nil? || order_id.empty?
        @error_message = "<font color='#ff0000' size='2'><b>取引IDが取得できませんでした</b></font><br/><br/>"
    end
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 要求DTOを生成し、値を設定します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # Commonパラメータクラスへのセット
    common_param = Veritrans::Tercerog::Mdk::CommonSearchParameter.new
    common_param.order_id = order_id
    # Searchパラメータクラスへのセット
    search_param = Veritrans::Tercerog::Mdk::SearchParameters.new
    search_param.common = common_param
    # 設定
    amazonpay_param = Veritrans::Tercerog::Mdk::AmazonpaySearchParameter.new
    amazonpay_param.detail_command_type = Array.new
    # 検索パラメータに設定
    search_param.amazonpay = amazonpay_param
    # 検索DTOへパラメータクラスをセット
    request_data = Veritrans::Tercerog::Mdk::SearchRequestDto.new
    request_data.service_type_cd    = Array.new(["amazonpay"]) # Amazon Payのみ指定
    request_data.contain_dummy_flag = "1"                      # 検索対象にダミー決済のレコードを含めるかを示す
    request_data.search_parameters  = search_param             # 各機能の固有条件
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # コマンドを実行し、応答DTOを取得します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    tran = Veritrans::Tercerog::Mdk::MdkTransaction.new
    response_data = tran.execute(request_data)
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 結果画面に表示します。
    # +++++++++++++++++++++++++++++++++++++++++++++++++++++
    # 処理結果メッセージを設定（View機能へ引き渡す）
    warning = response_data.merr_msg
    if !warning.nil? && !warning.empty?
        @error_message = "<font color='#ff0000' size='2'><b>" + warning + "</b></font><br/><br/>"
    end
    # 配列データを設定（View機能へ引き渡す）
    order_infos = response_data.order_infos
    if !order_infos.nil?
        @order_info = order_infos.order_info
    end
  end

end
