# -*- encoding: utf-8 -*-
module MdkValidation

  ER_MSG = { :amount => "必須項目：金額が指定されていません",
    :amount_invalid =>"不正項目：金額には100以上の値を指定してください",
    :success_url =>"必須項目：決済完了時URLが指定されていません",
    :error_url => "必須項目：決済エラー時URLが指定されていません",
    :currency => "必須項目：通貨が指定されていません",
    :commodity_name => "必須項目：商品名が指定されていません",
    :comment => "必須項目：返金理由が指定されていません",
    :order_id => "必須項目：取引IDが指定されていません" ,
    :term_url =>"必須項目：term urlが指定されていません",
    :customer_ip => "必須項目：customer IP が指定されていません"
  }

  def validate_upop_auth
    amt_present = is_present(params[:amount], :amount)
    order_id_present = is_present(params[:order_id], :order_id)
    term_url = is_present(params[:termUrl], :term_url)
    customer_ip = is_present(params[:customerIp], :customer_ip)
    return  amt_present unless amt_present.blank?
    return  order_id_present unless order_id_present.blank?
    return  term_url unless term_url.blank?
    return  customer_ip unless customer_ip.blank?
  end

  def validate_upop_cancel
    order_id = is_present(params[:orderId], :order_id)
    return order_id unless order_id.blank?
  end

  def validate_upop_refund
    amt_present = is_present(params[:amount], :amount)
    order_id = is_present(params[:orderId], :order_id)
    return amt_present unless amt_present.blank?
    return order_id unless order_id.blank?
  end

  def validate_upop_capture
    amt_present = is_present(params[:amount], :amount)
    order_id = is_present(params[:orderId], :order_id)
    return order_id unless order_id.blank?
    return amt_present unless amt_present.blank?
  end

  def validate_alipay_auth
    order_id_present = is_present(params[:order_id], :order_id)
    amt_present = is_present(params[:amount], :amount)
    currency_present = is_present(params[:currency], :currency)

    config = Veritrans::Tercerog::Mdk::MdkConfig.instance
    dummy_request = config[:DUMMY_REQUEST]
    amt_valid = "CNY".eql?(params[:currency]) && "1".eql?(dummy_request) && !params[:amount].blank? && params[:amount].to_i < 100 ? ER_MSG[:amount_invalid] : ""

    commodity_name_present = is_present(params[:commodityName], :commodity_name)
    success_url_present = is_present(params[:successUrl], :success_url)
    error_url_present = is_present(params[:errorUrl], :error_url)

    return order_id_present unless order_id_present.blank?
    return amt_present unless amt_present.blank?
    return currency_present unless currency_present.blank?
    return amt_valid unless amt_valid.blank?
    if params[:pay_type].to_i == 0
      return success_url_present unless success_url_present.blank?
      return error_url_present unless error_url_present.blank?
    end
    return commodity_name_present unless commodity_name_present.blank?

  end

  def validate_alipay_confirm
    order_id = is_present(params[:orderId], :order_id)
    return order_id unless order_id.blank?
  end

  def validate_alipay_refund
    amt_present = is_present(params[:amount], :amount)
    order_id = is_present(params[:orderId], :order_id)
    return order_id unless order_id.blank?
    return amt_present unless amt_present.blank?
  end

  def is_present(params, msg_key)
    err_msg = params.blank? ? ER_MSG[msg_key] : ''
    err_msg ||= ''
  end

end
